// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"fmt"
	"github.com/go-xorm/xorm"
	"LEIT_PM/grmi"
	meta "LEIT_PM/meta/base"
	model "LEIT_PM/models/base"
	"xorm.io/core"
)

/******************************************************************************
 *
 * @Struct Name              : LabelParserDetailLstDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : LabelParserDetailLst的数据访问对象实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 13:39:52
 *
 ******************************************************************************/
type LabelParserDetailLstDAOImplement struct {
	session *xorm.Session
	meta    *grmi.Entity
	plantNr int
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewLabelParserDetailLstDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个LabelParserDetailLstDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *
 * @Function Parameters      : 基本主键
 *
 * @Return Value             : LabelParserDetailLstDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 13:39:52
 *
 ******************************************************************************/
func NewLabelParserDetailLstDAOImplement(session *xorm.Session, plantNr int, userid string) *LabelParserDetailLstDAOImplement {
	return &LabelParserDetailLstDAOImplement{session, &meta.LabelParserDetailLst, plantNr, userid}
}

/******************************************************************************
 *
 * @Reference LEIT_PM/dao/base/LabelParserDetailLstDAO.InsertOne
 *
 ******************************************************************************/
func (impl *LabelParserDetailLstDAOImplement) InsertOne(entity *model.LabelParserDetailLst) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/dao/base/LabelParserDetailLstDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *LabelParserDetailLstDAOImplement) DeleteOne(parserId string, pos int) error {
	_, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, parserId, pos}).Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/dao/base/LabelParserDetailLstDAO.SelectOne
 *
 ******************************************************************************/
func (impl *LabelParserDetailLstDAOImplement) SelectOne(parserId string, pos int) (*model.LabelParserDetailLst, error) {
	var data model.LabelParserDetailLst
	ok, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, parserId, pos}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/dao/base/LabelParserDetailLstDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *LabelParserDetailLstDAOImplement) UpdateOne(entity *model.LabelParserDetailLst) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/dao/base/LabelParserDetailLstDAO.Insert
 *
 ******************************************************************************/
func (impl *LabelParserDetailLstDAOImplement) Insert(entities *[]model.LabelParserDetailLst) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
	}
	_, err := impl.session.Table(impl.meta.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/dao/base/LabelParserDetailLstDAO.Delete
 *
 ******************************************************************************/
func (impl *LabelParserDetailLstDAOImplement) Delete(entities *[]model.LabelParserDetailLst) error {
	for _, entity := range *entities {
		entity.PlantNr = impl.plantNr
		_, err := impl.session.Table(impl.meta.TableName).ID(entity.GetKey()).Delete(impl.meta.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/dao/base/LabelParserDetailLstDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *LabelParserDetailLstDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.LabelParserDetailLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/dao/base/LabelParserDetailLstDAO.Select
 *
 ******************************************************************************/
func (impl *LabelParserDetailLstDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.LabelParserDetailLst, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.LabelParserDetailLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	session = session.OrderBy(meta.LabelParserDetailLst_PlantNr.ColumnName)
	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]model.LabelParserDetailLst, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/dao/base/LabelParserDetailLstDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *LabelParserDetailLstDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.LabelParserDetailLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(impl.meta.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	orderBy := " order by " + meta.LabelParserDetailLst_PlantNr.ColumnName
	if orderByFields != nil {
		for _, field := range orderByFields {
			if orderBy == " order by " {
				orderBy += field.ColumnName
			} else {
				orderBy += ", " + field.ColumnName
			}
		}
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.LabelParserDetailLst, 0, 10)
	where = " where " + where
	err = impl.session.Table(impl.meta.TableName).SQL("select * from ["+impl.meta.TableName+"]"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/dao/base/LabelParserDetailLstDAO.Update
 *
 ******************************************************************************/
func (impl *LabelParserDetailLstDAOImplement) Update(entities *[]model.LabelParserDetailLst) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
		_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/dao/base/LabelParserDetailLstDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *LabelParserDetailLstDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.LabelParserDetailLst, columns ...string) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.LabelParserDetailLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.LabelParserDetailLst_LastUser.ColumnName)
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}
