// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package pj

import (
	"LEIT_PM/dao/pj/implments"
	"LEIT_PM/grmi"
	model "LEIT_PM/models/pj"
	"github.com/go-xorm/xorm"
)

/******************************************************************************
 *
 * @Interface Name           : ResourceDAO
 *-----------------------------------------------------------------------------
 *
 * @Description              : Resource的数据访问对象接口
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
type ResourceDAO interface {
	/******************************************************************************
	 *
	 * @Function Name            : InsertOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入一条Resource
	 *
	 * @Function Parameters      : 需要插入的Resource
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-09-06 13:59:55
	 *
	 ******************************************************************************/
	InsertOne(*model.Resource) error
	/******************************************************************************
	 *
	 * @Function Name            : DeleteOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除指定键的Resource
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-09-06 13:59:55
	 *
	 ******************************************************************************/
	DeleteOne(string) error
	/******************************************************************************
	 *
	 * @Function Name            : SelectOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查找指定键的Resource
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 查找到的Resource
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-09-06 13:59:55
	 *
	 ******************************************************************************/
	SelectOne(string) (*model.Resource, error)
	/******************************************************************************
	 *
	 * @Function Name            : UpdateOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改Resource
	 *
	 * @Function Parameters      : 需要修改的Resource
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-09-06 13:59:55
	 *
	 ******************************************************************************/
	UpdateOne(*model.Resource) error
	/******************************************************************************
	 *
	 * @Function Name            : Insert
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入多条Resource
	 *
	 * @Function Parameters      : 需要插入的Resource列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-09-06 13:59:55
	 *
	 ******************************************************************************/
	Insert(*[]model.Resource) error
	/******************************************************************************
	 *
	 * @Function Name            : Delete
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除多条Resource
	 *
	 * @Function Parameters      : 需要删除的Resource列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-09-06 13:59:55
	 *
	 ******************************************************************************/
	Delete(*[]model.Resource) error
	/******************************************************************************
	 *
	 * @Function Name            : DeleteWhere
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 按条件删除Resource
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-09-06 13:59:55
	 *
	 ******************************************************************************/
	DeleteWhere([]grmi.Predicate) error
	/******************************************************************************
	 *
	 * @Function Name            : Select
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 按条件查询Resource
	 *
	 * @Function Parameters      : 查询条件
	 *
	 * @Function Parameters      : 排序字段
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-09-06 13:59:55
	 *
	 ******************************************************************************/
	Select([]grmi.Predicate, []grmi.Field) ([]model.Resource, error)
	/******************************************************************************
	 *
	 * @Function Name            : SelectAndPaging
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 按条件查询Resource并分页
	 *
	 * @Function Parameters      : 分页信息
	 *
	 * @Function Parameters      : 查询条件
	 *
	 * @Function Parameters      : 排序字段
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-09-06 13:59:55
	 *
	 ******************************************************************************/
	SelectAndPaging(*grmi.Paging, []grmi.Predicate, []grmi.Field) (grmi.PagingResult, error)
	/******************************************************************************
	 *
	 * @Function Name            : Update
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改多条Resource
	 *
	 * @Function Parameters      : 需要修改的Resource列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-09-06 13:59:55
	 *
	 ******************************************************************************/
	Update(*[]model.Resource) error
	/******************************************************************************
	 *
	 * @Function Name            : UpdateWhere
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 按条件修改Resource
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-09-06 13:59:55
	 *
	 ******************************************************************************/
	UpdateWhere([]grmi.Predicate, *model.Resource, ...string) error
}

/******************************************************************************
 *
 * @Function Name            : NewResourceDAO
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个ResourceDAO实例
 *
 * @Function Parameters      : xorm会话
 *

 * @Return Value             : ResourceDAO实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func NewResourceDAO(session *xorm.Session, userid string) ResourceDAO {
	return implments.NewResourceDAOImplement(session, userid)
}
