// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LEIT_PM/grmi"
	meta "LEIT_PM/meta/pj"
	model "LEIT_PM/models/pj"
	"github.com/go-xorm/xorm"
	"xorm.io/core"
)

/******************************************************************************
 *
 * @Struct Name              : ProjectDocumentLstDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : ProjectDocumentLst的数据访问对象实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-09 11:17:04
 *
 ******************************************************************************/
type ProjectDocumentLstDAOImplement struct {
	session *xorm.Session
	meta    *grmi.Entity
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewProjectDocumentLstDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个ProjectDocumentLstDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *

 * @Return Value             : ProjectDocumentLstDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-09 11:17:04
 *
 ******************************************************************************/
func NewProjectDocumentLstDAOImplement(session *xorm.Session, userid string) *ProjectDocumentLstDAOImplement {
	return &ProjectDocumentLstDAOImplement{session, &meta.ProjectDocumentLst, userid}
}

/******************************************************************************
 *
 * @Reference LEIT_PM/dao/pj/ProjectDocumentLstDAO.InsertOne
 *
 ******************************************************************************/
func (impl *ProjectDocumentLstDAOImplement) InsertOne(entity *model.ProjectDocumentLst) error {

	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/dao/pj/ProjectDocumentLstDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *ProjectDocumentLstDAOImplement) DeleteOne(projectId string, pos int) error {
	_, err := impl.session.Table(impl.meta.TableName).ID(core.PK{projectId, pos}).Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/dao/pj/ProjectDocumentLstDAO.SelectOne
 *
 ******************************************************************************/
func (impl *ProjectDocumentLstDAOImplement) SelectOne(projectId string, pos int) (*model.ProjectDocumentLst, error) {
	var data model.ProjectDocumentLst
	ok, err := impl.session.Table(impl.meta.TableName).ID(core.PK{projectId, pos}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/dao/pj/ProjectDocumentLstDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *ProjectDocumentLstDAOImplement) UpdateOne(entity *model.ProjectDocumentLst) error {

	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/dao/pj/ProjectDocumentLstDAO.Insert
 *
 ******************************************************************************/
func (impl *ProjectDocumentLstDAOImplement) Insert(entities *[]model.ProjectDocumentLst) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]

		entity.LastUser = impl.userid
	}
	_, err := impl.session.Table(impl.meta.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/dao/pj/ProjectDocumentLstDAO.Delete
 *
 ******************************************************************************/
func (impl *ProjectDocumentLstDAOImplement) Delete(entities *[]model.ProjectDocumentLst) error {
	for _, entity := range *entities {

		_, err := impl.session.Table(impl.meta.TableName).ID(entity.GetKey()).Delete(impl.meta.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/dao/pj/ProjectDocumentLstDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *ProjectDocumentLstDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{}
	where := ""

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/dao/pj/ProjectDocumentLstDAO.Select
 *
 ******************************************************************************/
func (impl *ProjectDocumentLstDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.ProjectDocumentLst, error) {

	parameters := []interface{}{}
	where := "1 = 1 "

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]model.ProjectDocumentLst, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/dao/pj/ProjectDocumentLstDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *ProjectDocumentLstDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{}
	where := "1 = 1 "

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(impl.meta.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	orderBy := " order by "
	if orderByFields != nil {
		for _, field := range orderByFields {
			if orderBy == " order by " {
				orderBy += field.ColumnName
			} else {
				orderBy += ", " + field.ColumnName
			}
		}
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.ProjectDocumentLst, 0, 10)
	where = " where " + where
	err = impl.session.Table(impl.meta.TableName).SQL("select * from ["+impl.meta.TableName+"]"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/dao/pj/ProjectDocumentLstDAO.Update
 *
 ******************************************************************************/
func (impl *ProjectDocumentLstDAOImplement) Update(entities *[]model.ProjectDocumentLst) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]

		entity.LastUser = impl.userid
		_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/dao/pj/ProjectDocumentLstDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *ProjectDocumentLstDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.ProjectDocumentLst, columns ...string) error {

	parameters := []interface{}{}
	where := ""

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.ProjectDocumentLst_LastUser.Name)
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}
