// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LEIT_PM/grmi"
	meta "LEIT_PM/meta/pj"
	model "LEIT_PM/models/pj"
	"github.com/go-xorm/xorm"
	"xorm.io/core"
)

/******************************************************************************
 *
 * @Struct Name              : ProjectPaymentPhaseLstDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : ProjectPaymentPhaseLst的数据访问对象实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
type ProjectPaymentPhaseLstDAOImplement struct {
	session *xorm.Session
	meta    *grmi.Entity
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewProjectPaymentPhaseLstDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个ProjectPaymentPhaseLstDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *

 * @Return Value             : ProjectPaymentPhaseLstDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func NewProjectPaymentPhaseLstDAOImplement(session *xorm.Session, userid string) *ProjectPaymentPhaseLstDAOImplement {
	return &ProjectPaymentPhaseLstDAOImplement{session, &meta.ProjectPaymentPhaseLst, userid}
}

/******************************************************************************
 *
 * @Reference LEIT_PM/dao/pj/ProjectPaymentPhaseLstDAO.InsertOne
 *
 ******************************************************************************/
func (impl *ProjectPaymentPhaseLstDAOImplement) InsertOne(entity *model.ProjectPaymentPhaseLst) error {

	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/dao/pj/ProjectPaymentPhaseLstDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *ProjectPaymentPhaseLstDAOImplement) DeleteOne(projectId string, paymentPhaseId string) error {
	_, err := impl.session.Table(impl.meta.TableName).ID(core.PK{projectId, paymentPhaseId}).Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/dao/pj/ProjectPaymentPhaseLstDAO.SelectOne
 *
 ******************************************************************************/
func (impl *ProjectPaymentPhaseLstDAOImplement) SelectOne(projectId string, paymentPhaseId string) (*model.ProjectPaymentPhaseLst, error) {
	var data model.ProjectPaymentPhaseLst
	ok, err := impl.session.Table(impl.meta.TableName).ID(core.PK{projectId, paymentPhaseId}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/dao/pj/ProjectPaymentPhaseLstDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *ProjectPaymentPhaseLstDAOImplement) UpdateOne(entity *model.ProjectPaymentPhaseLst) error {

	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/dao/pj/ProjectPaymentPhaseLstDAO.Insert
 *
 ******************************************************************************/
func (impl *ProjectPaymentPhaseLstDAOImplement) Insert(entities *[]model.ProjectPaymentPhaseLst) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]

		entity.LastUser = impl.userid
	}
	_, err := impl.session.Table(impl.meta.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/dao/pj/ProjectPaymentPhaseLstDAO.Delete
 *
 ******************************************************************************/
func (impl *ProjectPaymentPhaseLstDAOImplement) Delete(entities *[]model.ProjectPaymentPhaseLst) error {
	for _, entity := range *entities {

		_, err := impl.session.Table(impl.meta.TableName).ID(entity.GetKey()).Delete(impl.meta.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/dao/pj/ProjectPaymentPhaseLstDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *ProjectPaymentPhaseLstDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{}
	where := "1 = 1 "

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/dao/pj/ProjectPaymentPhaseLstDAO.Select
 *
 ******************************************************************************/
func (impl *ProjectPaymentPhaseLstDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.ProjectPaymentPhaseLst, error) {

	parameters := []interface{}{}
	where := "1 = 1 "

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]model.ProjectPaymentPhaseLst, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/dao/pj/ProjectPaymentPhaseLstDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *ProjectPaymentPhaseLstDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{}
	where := "1 = 1 "

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(impl.meta.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	orderBy := " order by "
	if orderByFields != nil {
		for _, field := range orderByFields {
			if orderBy == " order by " {
				orderBy += field.ColumnName
			} else {
				orderBy += ", " + field.ColumnName
			}
		}
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.ProjectPaymentPhaseLst, 0, 10)
	where = " where " + where
	err = impl.session.Table(impl.meta.TableName).SQL("select * from ["+impl.meta.TableName+"]"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/dao/pj/ProjectPaymentPhaseLstDAO.Update
 *
 ******************************************************************************/
func (impl *ProjectPaymentPhaseLstDAOImplement) Update(entities *[]model.ProjectPaymentPhaseLst) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]

		entity.LastUser = impl.userid
		_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/dao/pj/ProjectPaymentPhaseLstDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *ProjectPaymentPhaseLstDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.ProjectPaymentPhaseLst, columns ...string) error {

	parameters := []interface{}{}
	where := ""

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.ProjectPaymentPhaseLst_LastUser.Name)
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}
