// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LEIT_PM/grmi"
	meta "LEIT_PM/meta/pj"
	model "LEIT_PM/models/pj"
	"github.com/go-xorm/xorm"
	"xorm.io/core"
)

/******************************************************************************
 *
 * @Struct Name              : ProjectPhaseResourceLstDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : ProjectPhaseResourceLst的数据访问对象实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
type ProjectPhaseResourceLstDAOImplement struct {
	session *xorm.Session
	meta    *grmi.Entity
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewProjectPhaseResourceLstDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个ProjectPhaseResourceLstDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *

 * @Return Value             : ProjectPhaseResourceLstDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func NewProjectPhaseResourceLstDAOImplement(session *xorm.Session, userid string) *ProjectPhaseResourceLstDAOImplement {
	return &ProjectPhaseResourceLstDAOImplement{session, &meta.ProjectPhaseResourceLst, userid}
}

/******************************************************************************
 *
 * @Reference LEIT_PM/dao/pj/ProjectPhaseResourceLstDAO.InsertOne
 *
 ******************************************************************************/
func (impl *ProjectPhaseResourceLstDAOImplement) InsertOne(entity *model.ProjectPhaseResourceLst) error {

	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/dao/pj/ProjectPhaseResourceLstDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *ProjectPhaseResourceLstDAOImplement) DeleteOne(projectId string, phaseId string, resourceId string, planStartDate grmi.Date) error {
	_, err := impl.session.Table(impl.meta.TableName).ID(core.PK{projectId, phaseId, resourceId, planStartDate.ToString()}).Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/dao/pj/ProjectPhaseResourceLstDAO.SelectOne
 *
 ******************************************************************************/
func (impl *ProjectPhaseResourceLstDAOImplement) SelectOne(projectId string, phaseId string, resourceId string, planStartDate grmi.Date) (*model.ProjectPhaseResourceLst, error) {
	var data model.ProjectPhaseResourceLst
	ok, err := impl.session.Table(impl.meta.TableName).ID(core.PK{projectId, phaseId, resourceId, planStartDate.ToString()}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/dao/pj/ProjectPhaseResourceLstDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *ProjectPhaseResourceLstDAOImplement) UpdateOne(entity *model.ProjectPhaseResourceLst) error {

	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/dao/pj/ProjectPhaseResourceLstDAO.Insert
 *
 ******************************************************************************/
func (impl *ProjectPhaseResourceLstDAOImplement) Insert(entities *[]model.ProjectPhaseResourceLst) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]

		entity.LastUser = impl.userid
	}
	_, err := impl.session.Table(impl.meta.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/dao/pj/ProjectPhaseResourceLstDAO.Delete
 *
 ******************************************************************************/
func (impl *ProjectPhaseResourceLstDAOImplement) Delete(entities *[]model.ProjectPhaseResourceLst) error {
	for _, entity := range *entities {

		_, err := impl.session.Table(impl.meta.TableName).ID(entity.GetKey()).Delete(impl.meta.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/dao/pj/ProjectPhaseResourceLstDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *ProjectPhaseResourceLstDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{}
	where := "1 = 1 "

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/dao/pj/ProjectPhaseResourceLstDAO.Select
 *
 ******************************************************************************/
func (impl *ProjectPhaseResourceLstDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.ProjectPhaseResourceLst, error) {

	parameters := []interface{}{}
	where := "1 = 1 "

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]model.ProjectPhaseResourceLst, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/dao/pj/ProjectPhaseResourceLstDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *ProjectPhaseResourceLstDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{}
	where := "1 = 1 "

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(impl.meta.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	orderBy := " order by "
	if orderByFields != nil {
		for _, field := range orderByFields {
			if orderBy == " order by " {
				orderBy += field.ColumnName
			} else {
				orderBy += ", " + field.ColumnName
			}
		}
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.ProjectPhaseResourceLst, 0, 10)
	where = " where " + where
	err = impl.session.Table(impl.meta.TableName).SQL("select * from ["+impl.meta.TableName+"]"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/dao/pj/ProjectPhaseResourceLstDAO.Update
 *
 ******************************************************************************/
func (impl *ProjectPhaseResourceLstDAOImplement) Update(entities *[]model.ProjectPhaseResourceLst) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]

		entity.LastUser = impl.userid
		_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/dao/pj/ProjectPhaseResourceLstDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *ProjectPhaseResourceLstDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.ProjectPhaseResourceLst, columns ...string) error {

	parameters := []interface{}{}
	where := ""

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.ProjectPhaseResourceLst_LastUser.Name)
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}
