// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	dal "LEIT_PM/dao/base"
	"LEIT_PM/db"
	"LEIT_PM/global"
	"LEIT_PM/grmi"
	meta "LEIT_PM/meta/base"
	model "LEIT_PM/models/base"
)

/******************************************************************************
 *
 * @Description              : CodeParser的默认查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 11:11:05
 *
 ******************************************************************************/
var DefaultConditionOfCodeParser = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.CodeParser_ParserId.UrlParameterName:   grmi.NewConditionItem(meta.CodeParser_ParserId, grmi.Equal, true),
		meta.CodeParser_StartPos.UrlParameterName:   grmi.NewConditionItem(meta.CodeParser_StartPos, grmi.Equal, false),
		meta.CodeParser_Length.UrlParameterName:     grmi.NewConditionItem(meta.CodeParser_Length, grmi.Equal, false),
		meta.CodeParser_ParserType.UrlParameterName: grmi.NewConditionItem(meta.CodeParser_ParserType, grmi.Equal, false),
		meta.CodeParser_Descr.UrlParameterName:      grmi.NewConditionItem(meta.CodeParser_Descr, grmi.Equal, false),
		meta.CodeParser_LastModify.UrlParameterName: grmi.NewConditionItem(meta.CodeParser_LastModify, grmi.Approximate, false),
		meta.CodeParser_LastUser.UrlParameterName:   grmi.NewConditionItem(meta.CodeParser_LastUser, grmi.Equal, false),
		meta.CodeParser_CreateTime.UrlParameterName: grmi.NewConditionItem(meta.CodeParser_CreateTime, grmi.Approximate, false),
	},
	nil,
)

/******************************************************************************
 *
 * @Description              : CodeParser的默认分页查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 11:11:05
 *
 ******************************************************************************/
var DefaultConditionOfCodeParserAndPaging = grmi.NewCondition(
	DefaultConditionOfCodeParser.Items,
	grmi.NewPaging(),
)

/******************************************************************************
 *
 * @Struct Name              : CodeParserServiceImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : CodeParser的服务实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 11:11:05
 *
 ******************************************************************************/
type CodeParserServiceImplement struct {
}

/******************************************************************************
 *
 * @Function Name            : NewCodeParserDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个CodeParserDAOImplement实例
 *
 * @Return Value             : CodeParserDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 11:11:05
 *
 ******************************************************************************/
func NewCodeParserServiceImplement() *CodeParserServiceImplement {
	return &CodeParserServiceImplement{}
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/base/CodeParserService.InsertOne
 *
 ******************************************************************************/
func (impl *CodeParserServiceImplement) InsertOne(user *global.User, entity *model.CodeParser) error {

	grmi.Log(user, "/services/base/implments/CodeParser.service.impl.go", "InsertOneCodeParser", "插入一个CodeParser")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewCodeParserDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(entity.ParserId)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/base/CodeParserService.DeleteOne
 *
 ******************************************************************************/
func (impl *CodeParserServiceImplement) DeleteOne(user *global.User, parserId string) error {

	grmi.Log(user, "/services/base/implments/CodeParser.service.impl.go", "DeleteOneCodeParser", "删除一个CodeParser")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewCodeParserDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(parserId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(parserId)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/base/CodeParserService.SelectOne
 *
 ******************************************************************************/
func (impl *CodeParserServiceImplement) SelectOne(user *global.User, parserId string) (*model.CodeParser, error) {

	grmi.Log(user, "/services/base/implments/CodeParser.service.impl.go", "SelectOneCodeParser", "查询一个CodeParser")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewCodeParserDAO(session, user.PlantNr, user.UserId)
	result, err := dao.SelectOne(parserId)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/base/CodeParserService.UpdateOne
 *
 ******************************************************************************/
func (impl *CodeParserServiceImplement) UpdateOne(user *global.User, entity *model.CodeParser) error {

	grmi.Log(user, "/services/base/implments/CodeParser.service.impl.go", "UpdateOneCodeParser", "修改一个CodeParser")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewCodeParserDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(entity.ParserId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/base/CodeParserService.Insert
 *
 ******************************************************************************/
func (impl *CodeParserServiceImplement) Insert(user *global.User, entities *[]model.CodeParser) error {

	grmi.Log(user, "/services/base/implments/CodeParser.service.impl.go", "InsertCodeParser", "插入多个CodeParser")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewCodeParserDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.ParserId)
		if err != nil {
			return err
		}
		if record != nil {
			return grmi.NewBusinessError("已经存在相同主键的记录!")
		}
	}

	err := dao.Insert(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/base/CodeParserService.Delete
 *
 ******************************************************************************/
func (impl *CodeParserServiceImplement) Delete(user *global.User, entities *[]model.CodeParser) error {

	grmi.Log(user, "/services/base/implments/CodeParser.service.impl.go", "DeleteCodeParser", "删除多个CodeParser")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewCodeParserDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.ParserId)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Delete(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/base/CodeParserService.Select
 *
 ******************************************************************************/
func (impl *CodeParserServiceImplement) Select(user *global.User, urlParameters map[string]string) ([]model.CodeParser, error) {

	grmi.Log(user, "/services/base/implments/CodeParser.service.impl.go", "SelectCodeParser", "查询CodeParser")

	condition := DefaultConditionOfCodeParserAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewCodeParserDAO(session, user.PlantNr, user.UserId)
	result, err := dao.Select(predicates, condition.OrderByFields)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/base/CodeParserService.SelectAndPaging
 *
 ******************************************************************************/
func (impl *CodeParserServiceImplement) SelectAndPaging(user *global.User, urlParameters map[string]string) (grmi.PagingResult, error) {

	grmi.Log(user, "/services/base/implments/CodeParser.service.impl.go", "SelectCodeParser", "查询CodeParser")

	condition := DefaultConditionOfCodeParserAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	dao := dal.NewCodeParserDAO(session, user.PlantNr, user.UserId)
	condition.Fill(urlParameters)
	result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/base/CodeParserService.Update
 *
 ******************************************************************************/
func (impl *CodeParserServiceImplement) Update(user *global.User, entities *[]model.CodeParser) error {

	grmi.Log(user, "/services/base/implments/CodeParser.service.impl.go", "UpdateCodeParser", "修改多个CodeParser")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewCodeParserDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.ParserId)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Update(entities)
	if err != nil {
		return err
	}
	return nil
}
