// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	dal "LEIT_PM/dao/base"
	"LEIT_PM/db"
	"LEIT_PM/global"
	"LEIT_PM/grmi"
	meta "LEIT_PM/meta/base"
	model "LEIT_PM/models/base"
)

/******************************************************************************
 *
 * @Description              : ScriptItem的默认查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 11:11:05
 *
 ******************************************************************************/
var DefaultConditionOfScriptItem = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.ScriptItem_Script.UrlParameterName:       grmi.NewConditionItem(meta.ScriptItem_Script, grmi.Equal, true),
		meta.ScriptItem_TabMapCol.UrlParameterName:    grmi.NewConditionItem(meta.ScriptItem_TabMapCol, grmi.Equal, true),
		meta.ScriptItem_ColNo.UrlParameterName:        grmi.NewConditionItem(meta.ScriptItem_ColNo, grmi.Equal, false),
		meta.ScriptItem_ColName.UrlParameterName:      grmi.NewConditionItem(meta.ScriptItem_ColName, grmi.Equal, false),
		meta.ScriptItem_RowNo.UrlParameterName:        grmi.NewConditionItem(meta.ScriptItem_RowNo, grmi.Equal, false),
		meta.ScriptItem_RowName.UrlParameterName:      grmi.NewConditionItem(meta.ScriptItem_RowName, grmi.Equal, false),
		meta.ScriptItem_ColFieldType.UrlParameterName: grmi.NewConditionItem(meta.ScriptItem_ColFieldType, grmi.Equal, false),
		meta.ScriptItem_ColFormat.UrlParameterName:    grmi.NewConditionItem(meta.ScriptItem_ColFormat, grmi.Equal, false),
		meta.ScriptItem_DefaultValue.UrlParameterName: grmi.NewConditionItem(meta.ScriptItem_DefaultValue, grmi.Equal, false),
		meta.ScriptItem_LastModify.UrlParameterName:   grmi.NewConditionItem(meta.ScriptItem_LastModify, grmi.Approximate, false),
		meta.ScriptItem_LastUser.UrlParameterName:     grmi.NewConditionItem(meta.ScriptItem_LastUser, grmi.Equal, false),
		meta.ScriptItem_CreateTime.UrlParameterName:   grmi.NewConditionItem(meta.ScriptItem_CreateTime, grmi.Approximate, false),
	},
	nil,
)

/******************************************************************************
 *
 * @Description              : ScriptItem的默认分页查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 11:11:05
 *
 ******************************************************************************/
var DefaultConditionOfScriptItemAndPaging = grmi.NewCondition(
	DefaultConditionOfScriptItem.Items,
	grmi.NewPaging(),
)

/******************************************************************************
 *
 * @Struct Name              : ScriptItemServiceImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : ScriptItem的服务实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 11:11:05
 *
 ******************************************************************************/
type ScriptItemServiceImplement struct {
}

/******************************************************************************
 *
 * @Function Name            : NewScriptItemDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个ScriptItemDAOImplement实例
 *
 * @Return Value             : ScriptItemDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 11:11:05
 *
 ******************************************************************************/
func NewScriptItemServiceImplement() *ScriptItemServiceImplement {
	return &ScriptItemServiceImplement{}
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/base/ScriptItemService.InsertOne
 *
 ******************************************************************************/
func (impl *ScriptItemServiceImplement) InsertOne(user *global.User, entity *model.ScriptItem) error {

	grmi.Log(user, "/services/base/implments/ScriptItem.service.impl.go", "InsertOneScriptItem", "插入一个ScriptItem")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewScriptItemDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(entity.Script, entity.TabMapCol)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/base/ScriptItemService.DeleteOne
 *
 ******************************************************************************/
func (impl *ScriptItemServiceImplement) DeleteOne(user *global.User, script string, tabMapCol string) error {

	grmi.Log(user, "/services/base/implments/ScriptItem.service.impl.go", "DeleteOneScriptItem", "删除一个ScriptItem")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewScriptItemDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(script, tabMapCol)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(script, tabMapCol)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/base/ScriptItemService.SelectOne
 *
 ******************************************************************************/
func (impl *ScriptItemServiceImplement) SelectOne(user *global.User, script string, tabMapCol string) (*model.ScriptItem, error) {

	grmi.Log(user, "/services/base/implments/ScriptItem.service.impl.go", "SelectOneScriptItem", "查询一个ScriptItem")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewScriptItemDAO(session, user.PlantNr, user.UserId)
	result, err := dao.SelectOne(script, tabMapCol)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/base/ScriptItemService.UpdateOne
 *
 ******************************************************************************/
func (impl *ScriptItemServiceImplement) UpdateOne(user *global.User, entity *model.ScriptItem) error {

	grmi.Log(user, "/services/base/implments/ScriptItem.service.impl.go", "UpdateOneScriptItem", "修改一个ScriptItem")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewScriptItemDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(entity.Script, entity.TabMapCol)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/base/ScriptItemService.Insert
 *
 ******************************************************************************/
func (impl *ScriptItemServiceImplement) Insert(user *global.User, entities *[]model.ScriptItem) error {

	grmi.Log(user, "/services/base/implments/ScriptItem.service.impl.go", "InsertScriptItem", "插入多个ScriptItem")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewScriptItemDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.Script, entity.TabMapCol)
		if err != nil {
			return err
		}
		if record != nil {
			return grmi.NewBusinessError("已经存在相同主键的记录!")
		}
	}

	err := dao.Insert(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/base/ScriptItemService.Delete
 *
 ******************************************************************************/
func (impl *ScriptItemServiceImplement) Delete(user *global.User, entities *[]model.ScriptItem) error {

	grmi.Log(user, "/services/base/implments/ScriptItem.service.impl.go", "DeleteScriptItem", "删除多个ScriptItem")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewScriptItemDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.Script, entity.TabMapCol)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Delete(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/base/ScriptItemService.Select
 *
 ******************************************************************************/
func (impl *ScriptItemServiceImplement) Select(user *global.User, urlParameters map[string]string) ([]model.ScriptItem, error) {

	grmi.Log(user, "/services/base/implments/ScriptItem.service.impl.go", "SelectScriptItem", "查询ScriptItem")

	condition := DefaultConditionOfScriptItemAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewScriptItemDAO(session, user.PlantNr, user.UserId)
	result, err := dao.Select(predicates, condition.OrderByFields)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/base/ScriptItemService.SelectAndPaging
 *
 ******************************************************************************/
func (impl *ScriptItemServiceImplement) SelectAndPaging(user *global.User, urlParameters map[string]string) (grmi.PagingResult, error) {

	grmi.Log(user, "/services/base/implments/ScriptItem.service.impl.go", "SelectScriptItem", "查询ScriptItem")

	condition := DefaultConditionOfScriptItemAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	dao := dal.NewScriptItemDAO(session, user.PlantNr, user.UserId)
	condition.Fill(urlParameters)
	result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/base/ScriptItemService.Update
 *
 ******************************************************************************/
func (impl *ScriptItemServiceImplement) Update(user *global.User, entities *[]model.ScriptItem) error {

	grmi.Log(user, "/services/base/implments/ScriptItem.service.impl.go", "UpdateScriptItem", "修改多个ScriptItem")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewScriptItemDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.Script, entity.TabMapCol)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Update(entities)
	if err != nil {
		return err
	}
	return nil
}
