// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	dal "LEIT_PM/dao/base"
	"LEIT_PM/db"
	"LEIT_PM/global"
	"LEIT_PM/grmi"
	meta "LEIT_PM/meta/base"
	model "LEIT_PM/models/base"
)

/******************************************************************************
 *
 * @Description              : Uom的默认查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 11:11:05
 *
 ******************************************************************************/
var DefaultConditionOfUom = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.Uom_UomId.UrlParameterName:          grmi.NewConditionItem(meta.Uom_UomId, grmi.Equal, true),
		meta.Uom_UomName.UrlParameterName:        grmi.NewConditionItem(meta.Uom_UomName, grmi.Equal, false),
		meta.Uom_UomType.UrlParameterName:        grmi.NewConditionItem(meta.Uom_UomType, grmi.Equal, false),
		meta.Uom_BasicUomToggle.UrlParameterName: grmi.NewConditionItem(meta.Uom_BasicUomToggle, grmi.Equal, false),
		meta.Uom_BasicUom.UrlParameterName:       grmi.NewConditionItem(meta.Uom_BasicUom, grmi.Equal, false),
		meta.Uom_ConvertRatio.UrlParameterName:   grmi.NewConditionItem(meta.Uom_ConvertRatio, grmi.Equal, false),
		meta.Uom_LastModify.UrlParameterName:     grmi.NewConditionItem(meta.Uom_LastModify, grmi.Approximate, false),
		meta.Uom_LastUser.UrlParameterName:       grmi.NewConditionItem(meta.Uom_LastUser, grmi.Equal, false),
		meta.Uom_CreateTime.UrlParameterName:     grmi.NewConditionItem(meta.Uom_CreateTime, grmi.Approximate, false),
	},
	nil,
)

/******************************************************************************
 *
 * @Description              : Uom的默认分页查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 11:11:05
 *
 ******************************************************************************/
var DefaultConditionOfUomAndPaging = grmi.NewCondition(
	DefaultConditionOfUom.Items,
	grmi.NewPaging(),
)

/******************************************************************************
 *
 * @Struct Name              : UomServiceImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : Uom的服务实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 11:11:05
 *
 ******************************************************************************/
type UomServiceImplement struct {
}

/******************************************************************************
 *
 * @Function Name            : NewUomDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个UomDAOImplement实例
 *
 * @Return Value             : UomDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 11:11:05
 *
 ******************************************************************************/
func NewUomServiceImplement() *UomServiceImplement {
	return &UomServiceImplement{}
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/base/UomService.InsertOne
 *
 ******************************************************************************/
func (impl *UomServiceImplement) InsertOne(user *global.User, entity *model.Uom) error {

	grmi.Log(user, "/services/base/implments/Uom.service.impl.go", "InsertOneUom", "插入一个Uom")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewUomDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(entity.UomId)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/base/UomService.DeleteOne
 *
 ******************************************************************************/
func (impl *UomServiceImplement) DeleteOne(user *global.User, uomId string) error {

	grmi.Log(user, "/services/base/implments/Uom.service.impl.go", "DeleteOneUom", "删除一个Uom")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewUomDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(uomId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(uomId)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/base/UomService.SelectOne
 *
 ******************************************************************************/
func (impl *UomServiceImplement) SelectOne(user *global.User, uomId string) (*model.Uom, error) {

	grmi.Log(user, "/services/base/implments/Uom.service.impl.go", "SelectOneUom", "查询一个Uom")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewUomDAO(session, user.PlantNr, user.UserId)
	result, err := dao.SelectOne(uomId)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/base/UomService.UpdateOne
 *
 ******************************************************************************/
func (impl *UomServiceImplement) UpdateOne(user *global.User, entity *model.Uom) error {

	grmi.Log(user, "/services/base/implments/Uom.service.impl.go", "UpdateOneUom", "修改一个Uom")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewUomDAO(session, user.PlantNr, user.UserId)
	record, err := dao.SelectOne(entity.UomId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/base/UomService.Insert
 *
 ******************************************************************************/
func (impl *UomServiceImplement) Insert(user *global.User, entities *[]model.Uom) error {

	grmi.Log(user, "/services/base/implments/Uom.service.impl.go", "InsertUom", "插入多个Uom")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewUomDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.UomId)
		if err != nil {
			return err
		}
		if record != nil {
			return grmi.NewBusinessError("已经存在相同主键的记录!")
		}
	}

	err := dao.Insert(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/base/UomService.Delete
 *
 ******************************************************************************/
func (impl *UomServiceImplement) Delete(user *global.User, entities *[]model.Uom) error {

	grmi.Log(user, "/services/base/implments/Uom.service.impl.go", "DeleteUom", "删除多个Uom")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewUomDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.UomId)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Delete(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/base/UomService.Select
 *
 ******************************************************************************/
func (impl *UomServiceImplement) Select(user *global.User, urlParameters map[string]string) ([]model.Uom, error) {

	grmi.Log(user, "/services/base/implments/Uom.service.impl.go", "SelectUom", "查询Uom")

	condition := DefaultConditionOfUomAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewUomDAO(session, user.PlantNr, user.UserId)
	result, err := dao.Select(predicates, condition.OrderByFields)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/base/UomService.SelectAndPaging
 *
 ******************************************************************************/
func (impl *UomServiceImplement) SelectAndPaging(user *global.User, urlParameters map[string]string) (grmi.PagingResult, error) {

	grmi.Log(user, "/services/base/implments/Uom.service.impl.go", "SelectUom", "查询Uom")

	condition := DefaultConditionOfUomAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	dao := dal.NewUomDAO(session, user.PlantNr, user.UserId)
	condition.Fill(urlParameters)
	result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/base/UomService.Update
 *
 ******************************************************************************/
func (impl *UomServiceImplement) Update(user *global.User, entities *[]model.Uom) error {

	grmi.Log(user, "/services/base/implments/Uom.service.impl.go", "UpdateUom", "修改多个Uom")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewUomDAO(session, user.PlantNr, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.UomId)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Update(entities)
	if err != nil {
		return err
	}
	return nil
}
