// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package pj

import (
	"LEIT_PM/global"
	"LEIT_PM/grmi"
	model "LEIT_PM/models/pj"
	"LEIT_PM/services/pj/implments"
)

/******************************************************************************
 *
 * @Interface Name           : ResourceService
 *-----------------------------------------------------------------------------
 *
 * @Description              : Resource的服务接口
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
type ResourceService interface {
	/******************************************************************************
	 *
	 * @Function Name            : InsertOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入一条Resource
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要插入的Resource
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-09-06 13:59:55
	 *
	 ******************************************************************************/
	InsertOne(*global.User, *model.Resource) error
	/******************************************************************************
	 *
	 * @Function Name            : DeleteOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除指定键的Resource
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-09-06 13:59:55
	 *
	 ******************************************************************************/
	DeleteOne(*global.User, string) error
	/******************************************************************************
	 *
	 * @Function Name            : SelectOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查找指定键的Resource
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 查找到的Resource
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-09-06 13:59:55
	 *
	 ******************************************************************************/
	SelectOne(*global.User, string) (*model.Resource, error)
	/******************************************************************************
	 *
	 * @Function Name            : UpdateOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改一条Resource
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要修改的Resource
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-09-06 13:59:55
	 *
	 ******************************************************************************/
	UpdateOne(*global.User, *model.Resource) error
	/******************************************************************************
	 *
	 * @Function Name            : Insert
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入多条Resource
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要插入的Resource列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-09-06 13:59:55
	 *
	 ******************************************************************************/
	Insert(*global.User, *[]model.Resource) error
	/******************************************************************************
	 *
	 * @Function Name            : Delete
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除多条Resource
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要删除的Resource列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-09-06 13:59:55
	 *
	 ******************************************************************************/
	Delete(*global.User, *[]model.Resource) error
	/******************************************************************************
	 *
	 * @Function Name            : Select
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查询Resource
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 查询参数
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-09-06 13:59:55
	 *
	 ******************************************************************************/
	Select(*global.User, map[string]string) ([]model.Resource, error)
	/******************************************************************************
	 *
	 * @Function Name            : SelectAndPaging
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查询Resource
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 查询参数
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-09-06 13:59:55
	 *
	 ******************************************************************************/
	SelectAndPaging(*global.User, map[string]string) (grmi.PagingResult, error)
	/******************************************************************************
	 *
	 * @Function Name            : Update
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改多条Resource
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要修改的Resource列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-09-06 13:59:55
	 *
	 ******************************************************************************/
	Update(*global.User, *[]model.Resource) error
	/******************************************************************************
	 *
	 * @Function Name            : Enable
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 启动Resource
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : esource
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-09-06 13:59:55
	 *
	 ******************************************************************************/
	Enable(*global.User, string) error

	/******************************************************************************
	 *
	 * @Function Name            : Disable
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 启动Resource
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : esource
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-09-06 13:59:55
	 *
	 ******************************************************************************/
	Disable(*global.User, string) error
}

/******************************************************************************
 *
 * @Function Name            : NewResourceService
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个ResourceService
 *
 * @Return Value             : ResourceService实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func NewResourceService() ResourceService {
	return implments.NewResourceServiceImplement()
}
