// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	dal "LEIT_PM/dao/pj"
	"LEIT_PM/db"
	"LEIT_PM/global"
	"LEIT_PM/grmi"
	meta "LEIT_PM/meta/pj"
	model "LEIT_PM/models/pj"
)

/******************************************************************************
 *
 * @Description              : ExpenseType的默认查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-09 13:38:13
 *
 ******************************************************************************/
var DefaultConditionOfExpenseType = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.ExpenseType_ExpenseTypeId.UrlParameterName:       grmi.NewConditionItem(meta.ExpenseType_ExpenseTypeId, grmi.Equal, true),
		meta.ExpenseType_ParentExpenseTypeId.UrlParameterName: grmi.NewConditionItem(meta.ExpenseType_ParentExpenseTypeId, grmi.Equal, false),
		meta.ExpenseType_Descr.UrlParameterName:               grmi.NewConditionItem(meta.ExpenseType_Descr, grmi.Equal, false),
		meta.ExpenseType_Remark.UrlParameterName:              grmi.NewConditionItem(meta.ExpenseType_Remark, grmi.Equal, false),
		meta.ExpenseType_CtrlPara1.UrlParameterName:           grmi.NewConditionItem(meta.ExpenseType_CtrlPara1, grmi.Equal, false),
		meta.ExpenseType_CtrlPara2.UrlParameterName:           grmi.NewConditionItem(meta.ExpenseType_CtrlPara2, grmi.Equal, false),
		meta.ExpenseType_CtrlStr1.UrlParameterName:            grmi.NewConditionItem(meta.ExpenseType_CtrlStr1, grmi.Equal, false),
		meta.ExpenseType_CtrlStr2.UrlParameterName:            grmi.NewConditionItem(meta.ExpenseType_CtrlStr2, grmi.Equal, false),
		meta.ExpenseType_CtrlTime1.UrlParameterName:           grmi.NewConditionItem(meta.ExpenseType_CtrlTime1, grmi.Approximate, false),
		meta.ExpenseType_CtrlTime2.UrlParameterName:           grmi.NewConditionItem(meta.ExpenseType_CtrlTime2, grmi.Approximate, false),
		meta.ExpenseType_LastModify.UrlParameterName:          grmi.NewConditionItem(meta.ExpenseType_LastModify, grmi.Approximate, false),
		meta.ExpenseType_LastUser.UrlParameterName:            grmi.NewConditionItem(meta.ExpenseType_LastUser, grmi.Equal, false),
		meta.ExpenseType_CreateTime.UrlParameterName:          grmi.NewConditionItem(meta.ExpenseType_CreateTime, grmi.Approximate, false),
	},
	nil,
)

/******************************************************************************
 *
 * @Description              : ExpenseType的默认分页查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-09 13:38:13
 *
 ******************************************************************************/
var DefaultConditionOfExpenseTypeAndPaging = grmi.NewCondition(
	DefaultConditionOfExpenseType.Items,
	grmi.NewPaging(),
)

/******************************************************************************
 *
 * @Struct Name              : ExpenseTypeServiceImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : ExpenseType的服务实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-09 13:38:13
 *
 ******************************************************************************/
type ExpenseTypeServiceImplement struct {
}

/******************************************************************************
 *
 * @Function Name            : NewExpenseTypeDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个ExpenseTypeDAOImplement实例
 *
 * @Return Value             : ExpenseTypeDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-09 13:38:13
 *
 ******************************************************************************/
func NewExpenseTypeServiceImplement() *ExpenseTypeServiceImplement {
	return &ExpenseTypeServiceImplement{}
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/ExpenseTypeService.InsertOne
 *
 ******************************************************************************/
func (impl *ExpenseTypeServiceImplement) InsertOne(user *global.User, entity *model.ExpenseType) error {

	grmi.Log(user, "/services/pj/implments/ExpenseType.service.impl.go", "InsertOneExpenseType", "插入一个ExpenseType")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewExpenseTypeDAO(session, user.UserId)
	record, err := dao.SelectOne(entity.ExpenseTypeId)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/ExpenseTypeService.DeleteOne
 *
 ******************************************************************************/
func (impl *ExpenseTypeServiceImplement) DeleteOne(user *global.User, expenseTypeId string) error {

	grmi.Log(user, "/services/pj/implments/ExpenseType.service.impl.go", "DeleteOneExpenseType", "删除一个ExpenseType")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewExpenseTypeDAO(session, user.UserId)
	record, err := dao.SelectOne(expenseTypeId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(expenseTypeId)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/ExpenseTypeService.SelectOne
 *
 ******************************************************************************/
func (impl *ExpenseTypeServiceImplement) SelectOne(user *global.User, expenseTypeId string) (*model.ExpenseType, error) {

	grmi.Log(user, "/services/pj/implments/ExpenseType.service.impl.go", "SelectOneExpenseType", "查询一个ExpenseType")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewExpenseTypeDAO(session, user.UserId)
	result, err := dao.SelectOne(expenseTypeId)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/ExpenseTypeService.UpdateOne
 *
 ******************************************************************************/
func (impl *ExpenseTypeServiceImplement) UpdateOne(user *global.User, entity *model.ExpenseType) error {

	grmi.Log(user, "/services/pj/implments/ExpenseType.service.impl.go", "UpdateOneExpenseType", "修改一个ExpenseType")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewExpenseTypeDAO(session, user.UserId)
	record, err := dao.SelectOne(entity.ExpenseTypeId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/ExpenseTypeService.Insert
 *
 ******************************************************************************/
func (impl *ExpenseTypeServiceImplement) Insert(user *global.User, entities *[]model.ExpenseType) error {

	grmi.Log(user, "/services/pj/implments/ExpenseType.service.impl.go", "InsertExpenseType", "插入多个ExpenseType")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewExpenseTypeDAO(session, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.ExpenseTypeId)
		if err != nil {
			return err
		}
		if record != nil {
			return grmi.NewBusinessError("已经存在相同主键的记录!")
		}
	}

	err := dao.Insert(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/ExpenseTypeService.Delete
 *
 ******************************************************************************/
func (impl *ExpenseTypeServiceImplement) Delete(user *global.User, entities *[]model.ExpenseType) error {

	grmi.Log(user, "/services/pj/implments/ExpenseType.service.impl.go", "DeleteExpenseType", "删除多个ExpenseType")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewExpenseTypeDAO(session, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.ExpenseTypeId)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Delete(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/ExpenseTypeService.Select
 *
 ******************************************************************************/
func (impl *ExpenseTypeServiceImplement) Select(user *global.User, urlParameters map[string]string) ([]model.ExpenseType, error) {

	grmi.Log(user, "/services/pj/implments/ExpenseType.service.impl.go", "SelectExpenseType", "查询ExpenseType")

	condition := DefaultConditionOfExpenseTypeAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewExpenseTypeDAO(session, user.UserId)
	result, err := dao.Select(predicates, condition.OrderByFields)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/ExpenseTypeService.SelectAndPaging
 *
 ******************************************************************************/
func (impl *ExpenseTypeServiceImplement) SelectAndPaging(user *global.User, urlParameters map[string]string) (grmi.PagingResult, error) {

	grmi.Log(user, "/services/pj/implments/ExpenseType.service.impl.go", "SelectExpenseType", "查询ExpenseType")

	condition := DefaultConditionOfExpenseTypeAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	dao := dal.NewExpenseTypeDAO(session, user.UserId)
	condition.Fill(urlParameters)
	result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/ExpenseTypeService.Update
 *
 ******************************************************************************/
func (impl *ExpenseTypeServiceImplement) Update(user *global.User, entities *[]model.ExpenseType) error {

	grmi.Log(user, "/services/pj/implments/ExpenseType.service.impl.go", "UpdateExpenseType", "修改多个ExpenseType")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewExpenseTypeDAO(session, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.ExpenseTypeId)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Update(entities)
	if err != nil {
		return err
	}
	return nil
}
