// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	dal "LEIT_PM/dao/pj"
	"LEIT_PM/db"
	"LEIT_PM/global"
	"LEIT_PM/grmi"
	meta "LEIT_PM/meta/pj"
	model "LEIT_PM/models/pj"
)

/******************************************************************************
 *
 * @Description              : People的默认查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-09 11:00:02
 *
 ******************************************************************************/
var DefaultConditionOfPeople = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.People_Name.UrlParameterName:       grmi.NewConditionItem(meta.People_Name, grmi.Equal, true),
		meta.People_LastModify.UrlParameterName: grmi.NewConditionItem(meta.People_LastModify, grmi.Approximate, false),
		meta.People_LastUser.UrlParameterName:   grmi.NewConditionItem(meta.People_LastUser, grmi.Equal, false),
		meta.People_CreateTime.UrlParameterName: grmi.NewConditionItem(meta.People_CreateTime, grmi.Approximate, false),
	},
	nil,
)

/******************************************************************************
 *
 * @Description              : People的默认分页查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-09 11:00:02
 *
 ******************************************************************************/
var DefaultConditionOfPeopleAndPaging = grmi.NewCondition(
	DefaultConditionOfPeople.Items,
	grmi.NewPaging(),
)

/******************************************************************************
 *
 * @Struct Name              : PeopleServiceImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : People的服务实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-09 11:00:02
 *
 ******************************************************************************/
type PeopleServiceImplement struct {
}

/******************************************************************************
 *
 * @Function Name            : NewPeopleDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个PeopleDAOImplement实例
 *
 * @Return Value             : PeopleDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-09 11:00:02
 *
 ******************************************************************************/
func NewPeopleServiceImplement() *PeopleServiceImplement {
	return &PeopleServiceImplement{}
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/PeopleService.InsertOne
 *
 ******************************************************************************/
func (impl *PeopleServiceImplement) InsertOne(user *global.User, entity *model.People) error {

	grmi.Log(user, "/services/pj/implments/People.service.impl.go", "InsertOnePeople", "插入一个People")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewPeopleDAO(session, user.UserId)
	record, err := dao.SelectOne(entity.Name)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/PeopleService.DeleteOne
 *
 ******************************************************************************/
func (impl *PeopleServiceImplement) DeleteOne(user *global.User, name string) error {

	grmi.Log(user, "/services/pj/implments/People.service.impl.go", "DeleteOnePeople", "删除一个People")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewPeopleDAO(session, user.UserId)
	record, err := dao.SelectOne(name)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(name)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/PeopleService.SelectOne
 *
 ******************************************************************************/
func (impl *PeopleServiceImplement) SelectOne(user *global.User, name string) (*model.People, error) {

	grmi.Log(user, "/services/pj/implments/People.service.impl.go", "SelectOnePeople", "查询一个People")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewPeopleDAO(session, user.UserId)
	result, err := dao.SelectOne(name)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/PeopleService.UpdateOne
 *
 ******************************************************************************/
func (impl *PeopleServiceImplement) UpdateOne(user *global.User, entity *model.People) error {

	grmi.Log(user, "/services/pj/implments/People.service.impl.go", "UpdateOnePeople", "修改一个People")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewPeopleDAO(session, user.UserId)
	record, err := dao.SelectOne(entity.Name)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/PeopleService.Insert
 *
 ******************************************************************************/
func (impl *PeopleServiceImplement) Insert(user *global.User, entities *[]model.People) error {

	grmi.Log(user, "/services/pj/implments/People.service.impl.go", "InsertPeople", "插入多个People")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewPeopleDAO(session, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.Name)
		if err != nil {
			return err
		}
		if record != nil {
			return grmi.NewBusinessError("已经存在相同主键的记录!")
		}
	}

	err := dao.Insert(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/PeopleService.Delete
 *
 ******************************************************************************/
func (impl *PeopleServiceImplement) Delete(user *global.User, entities *[]model.People) error {

	grmi.Log(user, "/services/pj/implments/People.service.impl.go", "DeletePeople", "删除多个People")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewPeopleDAO(session, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.Name)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Delete(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/PeopleService.Select
 *
 ******************************************************************************/
func (impl *PeopleServiceImplement) Select(user *global.User, urlParameters map[string]string) ([]model.People, error) {

	grmi.Log(user, "/services/pj/implments/People.service.impl.go", "SelectPeople", "查询People")

	condition := DefaultConditionOfPeopleAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewPeopleDAO(session, user.UserId)
	result, err := dao.Select(predicates, condition.OrderByFields)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/PeopleService.SelectAndPaging
 *
 ******************************************************************************/
func (impl *PeopleServiceImplement) SelectAndPaging(user *global.User, urlParameters map[string]string) (grmi.PagingResult, error) {

	grmi.Log(user, "/services/pj/implments/People.service.impl.go", "SelectPeople", "查询People")

	condition := DefaultConditionOfPeopleAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	dao := dal.NewPeopleDAO(session, user.UserId)
	condition.Fill(urlParameters)
	result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/PeopleService.Update
 *
 ******************************************************************************/
func (impl *PeopleServiceImplement) Update(user *global.User, entities *[]model.People) error {

	grmi.Log(user, "/services/pj/implments/People.service.impl.go", "UpdatePeople", "修改多个People")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewPeopleDAO(session, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.Name)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Update(entities)
	if err != nil {
		return err
	}
	return nil
}
