// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	dal "LEIT_PM/dao/pj"
	"LEIT_PM/db"
	"LEIT_PM/global"
	"LEIT_PM/grmi"
	meta "LEIT_PM/meta/pj"
	model "LEIT_PM/models/pj"
)

/******************************************************************************
 *
 * @Description              : Phase的默认查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
var DefaultConditionOfPhase = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.Phase_PhaseId.UrlParameterName:    grmi.NewConditionItem(meta.Phase_PhaseId, grmi.Equal, true),
		meta.Phase_Descr.UrlParameterName:      grmi.NewConditionItem(meta.Phase_Descr, grmi.Equal, false),
		meta.Phase_PhaseType.UrlParameterName:  grmi.NewConditionItem(meta.Phase_PhaseType, grmi.Equal, false),
		meta.Phase_CtrlPara1.UrlParameterName:  grmi.NewConditionItem(meta.Phase_CtrlPara1, grmi.Equal, false),
		meta.Phase_CtrlPara2.UrlParameterName:  grmi.NewConditionItem(meta.Phase_CtrlPara2, grmi.Equal, false),
		meta.Phase_CtrlStr1.UrlParameterName:   grmi.NewConditionItem(meta.Phase_CtrlStr1, grmi.Equal, false),
		meta.Phase_CtrlStr2.UrlParameterName:   grmi.NewConditionItem(meta.Phase_CtrlStr2, grmi.Equal, false),
		meta.Phase_CtrlTime1.UrlParameterName:  grmi.NewConditionItem(meta.Phase_CtrlTime1, grmi.Approximate, false),
		meta.Phase_CtrlTime2.UrlParameterName:  grmi.NewConditionItem(meta.Phase_CtrlTime2, grmi.Approximate, false),
		meta.Phase_LastModify.UrlParameterName: grmi.NewConditionItem(meta.Phase_LastModify, grmi.Approximate, false),
		meta.Phase_LastUser.UrlParameterName:   grmi.NewConditionItem(meta.Phase_LastUser, grmi.Equal, false),
		meta.Phase_CreateTime.UrlParameterName: grmi.NewConditionItem(meta.Phase_CreateTime, grmi.Approximate, false),
	},
	nil,
)

/******************************************************************************
 *
 * @Description              : Phase的默认分页查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
var DefaultConditionOfPhaseAndPaging = grmi.NewCondition(
	DefaultConditionOfPhase.Items,
	grmi.NewPaging(),
)

/******************************************************************************
 *
 * @Struct Name              : PhaseServiceImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : Phase的服务实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
type PhaseServiceImplement struct {
}

/******************************************************************************
 *
 * @Function Name            : NewPhaseDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个PhaseDAOImplement实例
 *
 * @Return Value             : PhaseDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func NewPhaseServiceImplement() *PhaseServiceImplement {
	return &PhaseServiceImplement{}
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/PhaseService.InsertOne
 *
 ******************************************************************************/
func (impl *PhaseServiceImplement) InsertOne(user *global.User, entity *model.Phase) error {

	grmi.Log(user, "/services/pj/implments/Phase.service.impl.go", "InsertOnePhase", "插入一个Phase")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewPhaseDAO(session, user.UserId)
	record, err := dao.SelectOne(entity.PhaseId)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/PhaseService.DeleteOne
 *
 ******************************************************************************/
func (impl *PhaseServiceImplement) DeleteOne(user *global.User, phaseId string) error {

	grmi.Log(user, "/services/pj/implments/Phase.service.impl.go", "DeleteOnePhase", "删除一个Phase")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewPhaseDAO(session, user.UserId)
	record, err := dao.SelectOne(phaseId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(phaseId)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/PhaseService.SelectOne
 *
 ******************************************************************************/
func (impl *PhaseServiceImplement) SelectOne(user *global.User, phaseId string) (*model.Phase, error) {

	grmi.Log(user, "/services/pj/implments/Phase.service.impl.go", "SelectOnePhase", "查询一个Phase")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewPhaseDAO(session, user.UserId)
	result, err := dao.SelectOne(phaseId)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/PhaseService.UpdateOne
 *
 ******************************************************************************/
func (impl *PhaseServiceImplement) UpdateOne(user *global.User, entity *model.Phase) error {

	grmi.Log(user, "/services/pj/implments/Phase.service.impl.go", "UpdateOnePhase", "修改一个Phase")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewPhaseDAO(session, user.UserId)
	record, err := dao.SelectOne(entity.PhaseId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/PhaseService.Insert
 *
 ******************************************************************************/
func (impl *PhaseServiceImplement) Insert(user *global.User, entities *[]model.Phase) error {

	grmi.Log(user, "/services/pj/implments/Phase.service.impl.go", "InsertPhase", "插入多个Phase")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewPhaseDAO(session, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.PhaseId)
		if err != nil {
			return err
		}
		if record != nil {
			return grmi.NewBusinessError("已经存在相同主键的记录!")
		}
	}

	err := dao.Insert(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/PhaseService.Delete
 *
 ******************************************************************************/
func (impl *PhaseServiceImplement) Delete(user *global.User, entities *[]model.Phase) error {

	grmi.Log(user, "/services/pj/implments/Phase.service.impl.go", "DeletePhase", "删除多个Phase")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewPhaseDAO(session, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.PhaseId)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Delete(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/PhaseService.Select
 *
 ******************************************************************************/
func (impl *PhaseServiceImplement) Select(user *global.User, urlParameters map[string]string) ([]model.Phase, error) {

	grmi.Log(user, "/services/pj/implments/Phase.service.impl.go", "SelectPhase", "查询Phase")

	condition := DefaultConditionOfPhaseAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewPhaseDAO(session, user.UserId)
	result, err := dao.Select(predicates, condition.OrderByFields)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/PhaseService.SelectAndPaging
 *
 ******************************************************************************/
func (impl *PhaseServiceImplement) SelectAndPaging(user *global.User, urlParameters map[string]string) (grmi.PagingResult, error) {

	grmi.Log(user, "/services/pj/implments/Phase.service.impl.go", "SelectPhase", "查询Phase")

	condition := DefaultConditionOfPhaseAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	dao := dal.NewPhaseDAO(session, user.UserId)
	condition.Fill(urlParameters)
	result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/PhaseService.Update
 *
 ******************************************************************************/
func (impl *PhaseServiceImplement) Update(user *global.User, entities *[]model.Phase) error {

	grmi.Log(user, "/services/pj/implments/Phase.service.impl.go", "UpdatePhase", "修改多个Phase")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewPhaseDAO(session, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.PhaseId)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Update(entities)
	if err != nil {
		return err
	}
	return nil
}
