// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	dal_bass "LEIT_PM/dao/base"
	dal "LEIT_PM/dao/pj"
	"LEIT_PM/db"
	"LEIT_PM/global"
	"LEIT_PM/grmi"
	meta "LEIT_PM/meta/pj"
	model "LEIT_PM/models/pj"
)

/******************************************************************************
 *
 * @Description              : Project的默认查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
var DefaultConditionOfProject = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.Project_ProjectId.UrlParameterName:       grmi.NewConditionItem(meta.Project_ProjectId, grmi.Equal, true),
		meta.Project_Descr.UrlParameterName:           grmi.NewConditionItem(meta.Project_Descr, grmi.Equal, false),
		meta.Project_ProjectType.UrlParameterName:     grmi.NewConditionItem(meta.Project_ProjectType, grmi.Equal, false),
		meta.Project_ContractType.UrlParameterName:    grmi.NewConditionItem(meta.Project_ContractType, grmi.Equal, false),
		meta.Project_ProjectManager.UrlParameterName:  grmi.NewConditionItem(meta.Project_ProjectManager, grmi.Equal, false),
		meta.Project_PlanStartDate.UrlParameterName:   grmi.NewConditionItem(meta.Project_PlanStartDate, grmi.Approximate, false),
		meta.Project_PlanEndDate.UrlParameterName:     grmi.NewConditionItem(meta.Project_PlanEndDate, grmi.Approximate, false),
		meta.Project_ActualStartDate.UrlParameterName: grmi.NewConditionItem(meta.Project_ActualStartDate, grmi.Approximate, false),
		meta.Project_ActualEndDate.UrlParameterName:   grmi.NewConditionItem(meta.Project_ActualEndDate, grmi.Approximate, false),
		meta.Project_Budget.UrlParameterName:          grmi.NewConditionItem(meta.Project_Budget, grmi.Equal, false),
		meta.Project_ActualCost.UrlParameterName:      grmi.NewConditionItem(meta.Project_ActualCost, grmi.Equal, false),
		meta.Project_AmountPaid.UrlParameterName:      grmi.NewConditionItem(meta.Project_AmountPaid, grmi.Equal, false),
		meta.Project_Status.UrlParameterName:          grmi.NewConditionItem(meta.Project_Status, grmi.Equal, false),
		meta.Project_PaymentStatus.UrlParameterName:   grmi.NewConditionItem(meta.Project_PaymentStatus, grmi.Equal, false),
		meta.Project_CustomerId.UrlParameterName:      grmi.NewConditionItem(meta.Project_CustomerId, grmi.Equal, false),
		meta.Project_CustomerName.UrlParameterName:    grmi.NewConditionItem(meta.Project_CustomerName, grmi.Equal, false),
		meta.Project_Remark.UrlParameterName:          grmi.NewConditionItem(meta.Project_Remark, grmi.Equal, false),
		meta.Project_CtrlPara1.UrlParameterName:       grmi.NewConditionItem(meta.Project_CtrlPara1, grmi.Equal, false),
		meta.Project_CtrlPara2.UrlParameterName:       grmi.NewConditionItem(meta.Project_CtrlPara2, grmi.Equal, false),
		meta.Project_CtrlStr1.UrlParameterName:        grmi.NewConditionItem(meta.Project_CtrlStr1, grmi.Equal, false),
		meta.Project_CtrlStr2.UrlParameterName:        grmi.NewConditionItem(meta.Project_CtrlStr2, grmi.Equal, false),
		meta.Project_CtrlTime1.UrlParameterName:       grmi.NewConditionItem(meta.Project_CtrlTime1, grmi.Approximate, false),
		meta.Project_CtrlTime2.UrlParameterName:       grmi.NewConditionItem(meta.Project_CtrlTime2, grmi.Approximate, false),
		meta.Project_LastModify.UrlParameterName:      grmi.NewConditionItem(meta.Project_LastModify, grmi.Approximate, false),
		meta.Project_LastUser.UrlParameterName:        grmi.NewConditionItem(meta.Project_LastUser, grmi.Equal, false),
		meta.Project_CreateTime.UrlParameterName:      grmi.NewConditionItem(meta.Project_CreateTime, grmi.Approximate, false),
	},
	nil,
)

/******************************************************************************
 *
 * @Description              : Project的默认分页查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
var DefaultConditionOfProjectAndPaging = grmi.NewCondition(
	DefaultConditionOfProject.Items,
	grmi.NewPaging(),
)

/******************************************************************************
 *
 * @Struct Name              : ProjectServiceImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : Project的服务实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
type ProjectServiceImplement struct {
}

/******************************************************************************
 *
 * @Function Name            : NewProjectDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个ProjectDAOImplement实例
 *
 * @Return Value             : ProjectDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func NewProjectServiceImplement() *ProjectServiceImplement {
	return &ProjectServiceImplement{}
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/ProjectService.InsertOne
 *
 ******************************************************************************/
func (impl *ProjectServiceImplement) InsertOne(user *global.User, entity *model.Project) error {

	grmi.Log(user, "/services/pj/implments/Project.service.impl.go", "InsertOneProject", "插入一个Project")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewProjectDAO(session, user.UserId)

	snrDao := dal_bass.NewSnrDAO(session, user.PlantNr,user.UserId)
	projectId, err := snrDao.GetNextSnr(entity.ProjectType)
	if err != nil {
		return err
	}
	entity.ProjectId = projectId
	record, err := dao.SelectOne(entity.ProjectId)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}

	stdefDao := dal_bass.NewStdefDAO(session, user.UserId)
	stdef_ProjectType, err := stdefDao.SelectOne(entity.ProjectType,"PJ_Project-ProjectType","cn")
	if err != nil {
		return err
	}
	entity.ProjectType =stdef_ProjectType.Bez
	stdef_ContractType, err := stdefDao.SelectOne(entity.ContractType,"PJ_Project-ContractType","cn")
	if err != nil {
		return err
	}
	entity.ContractType =stdef_ContractType.Bez

	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/ProjectService.DeleteOne
 *
 ******************************************************************************/
func (impl *ProjectServiceImplement) DeleteOne(user *global.User, projectId string) error {

	grmi.Log(user, "/services/pj/implments/Project.service.impl.go", "DeleteOneProject", "删除一个Project")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	if err := session.Begin(); err != nil {
		return err
	}
	dao := dal.NewProjectDAO(session, user.UserId)
	record, err := dao.SelectOne(projectId)
	if err != nil {
		return err
	}
	if record == nil {
		session.Rollback()
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(projectId)
	if err != nil {
		session.Rollback()
		return err
	}

	dao_ProjectPhaseLst := dal.NewProjectPhaseLstDAO(session, user.UserId)
	err = dao_ProjectPhaseLst.DeleteWhere([]grmi.Predicate{
		meta.ProjectPhaseLst_ProjectId.NewPredicate(grmi.Equal, projectId),
	})
	if err != nil {
		session.Rollback()
		return err
	}

	dao_ProjectPaymentPhaseLst := dal.NewProjectPaymentPhaseLstDAO(session, user.UserId)
	err = dao_ProjectPaymentPhaseLst.DeleteWhere([]grmi.Predicate{
		meta.ProjectPaymentPhaseLst_ProjectId.NewPredicate(grmi.Equal, projectId),
	})
	if err != nil {
		session.Rollback()
		return err
	}

	dao_ProjectPhaseExpenseLst := dal.NewProjectPhaseExpenseLstDAO(session, user.UserId)
	err = dao_ProjectPhaseExpenseLst.DeleteWhere([]grmi.Predicate{
		meta.ProjectPhaseExpenseLst_ProjectId.NewPredicate(grmi.Equal, projectId),
	})
	if err != nil {
		session.Rollback()
		return err
	}

	dao_ProjectPhaseResourceLst := dal.NewProjectPhaseResourceLstDAO(session, user.UserId)
	err = dao_ProjectPhaseResourceLst.DeleteWhere([]grmi.Predicate{
		meta.ProjectPhaseResourceLst_ProjectId.NewPredicate(grmi.Equal, projectId),
	})
	if err != nil {
		session.Rollback()
		return err
	}

	session.Commit()
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/ProjectService.SelectOne
 *
 ******************************************************************************/
func (impl *ProjectServiceImplement) SelectOne(user *global.User, projectId string) (*model.Project, error) {

	grmi.Log(user, "/services/pj/implments/Project.service.impl.go", "SelectOneProject", "查询一个Project")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewProjectDAO(session, user.UserId)
	result, err := dao.SelectOne(projectId)
	if err != nil {
		return nil, err
	}
	if result == nil{
		return nil,grmi.NewBusinessError("不存在指定记录!")
	}

	paymentphase_dao := dal.NewProjectPaymentPhaseLstDAO(session, user.UserId)
	paymentphase_predicate := []grmi.Predicate{meta.ProjectPaymentPhaseLst_ProjectId.NewPredicate(grmi.Equal, result.ProjectId)}
	paymentphase_data, err := paymentphase_dao.Select(paymentphase_predicate,nil)
	if err != nil {
		return nil, err
	}
	result.PaymentPhases = paymentphase_data

	phaselst_dao := dal.NewProjectPhaseLstDAO(session, user.UserId)
	phaselst_predicate := []grmi.Predicate{meta.ProjectPhaseLst_ProjectId.NewPredicate(grmi.Equal, result.ProjectId)}
	phaselst_data, err := phaselst_dao.Select(phaselst_predicate,nil)
	if err != nil {
		return nil, err
	}

	phaseResouce_dao := dal.NewProjectPhaseResourceLstDAO(session, user.UserId)
	phaseExpense_dao := dal.NewProjectPhaseExpenseLstDAO(session, user.UserId)
	PhaseExpensePeopleLst_dao := dal.NewProjectPhaseExpensePeopleLstDAO(session, user.UserId)
	PhaseResourcePeopleLst_dao := dal.NewProjectPhaseResourcePeopleLstDAO(session, user.UserId)
	for index, phaseInfo := range phaselst_data{
		phaseResouce_predicate := []grmi.Predicate{meta.ProjectPhaseResourceLst_ProjectId.NewPredicate(grmi.Equal, phaseInfo.ProjectId),meta.ProjectPhaseResourceLst_PhaseId.NewPredicate(grmi.Equal, phaseInfo.PhaseId)}
		phaseResouce_data, err := phaseResouce_dao.Select(phaseResouce_predicate,nil)
		if err != nil {
			return nil, err
		}
		phaselst_data[index].Resources =  phaseResouce_data
		for index2,_ := range phaseResouce_data{
			phaseResouce_predicate := []grmi.Predicate{meta.ProjectPhaseResourcePeopleLst_ProjectId.NewPredicate(grmi.Equal, phaseResouce_data[index2].ProjectId),
				meta.ProjectPhaseResourcePeopleLst_PhaseId.NewPredicate(grmi.Equal, phaseResouce_data[index2].PhaseId),
				meta.ProjectPhaseResourcePeopleLst_ResourceId.NewPredicate(grmi.Equal, phaseResouce_data[index2].ResourceId),
				meta.ProjectPhaseResourcePeopleLst_PlanStartDate.NewPredicate(grmi.Equal, phaseResouce_data[index2].PlanStartDate.ToString()),
			}
			phaseResouce_predicate_data, err := PhaseResourcePeopleLst_dao.Select(phaseResouce_predicate,nil)
			if err != nil {
				return nil, err
			}
			phaselst_data[index].Resources[index2].ProjectPhaseResourcePeopleLst = phaseResouce_predicate_data
		}

		phaseExpense_predicate := []grmi.Predicate{meta.ProjectPhaseExpenseLst_ProjectId.NewPredicate(grmi.Equal, phaseInfo.ProjectId),meta.ProjectPhaseExpenseLst_PhaseId.NewPredicate(grmi.Equal, phaseInfo.PhaseId)}
		phaseExpense_data, err := phaseExpense_dao.Select(phaseExpense_predicate,nil)
		if err != nil {
			return nil, err
		}
		phaselst_data[index].Expenses =  phaseExpense_data
		for index3,_ := range phaseExpense_data{
			phaseResouce_predicate := []grmi.Predicate{meta.ProjectPhaseExpensePeopleLst_ProjectId.NewPredicate(grmi.Equal,  phaseExpense_data[index3].ProjectId),
				meta.ProjectPhaseExpensePeopleLst_PhaseId.NewPredicate(grmi.Equal,  phaseExpense_data[index3].PhaseId),
				meta.ProjectPhaseExpensePeopleLst_Pos.NewPredicate(grmi.Equal, phaseExpense_data[index3].Pos),
			}
			phaseResouce_predicate_data, err := PhaseExpensePeopleLst_dao.Select(phaseResouce_predicate,nil)
			if err != nil {
				return nil, err
			}
			phaselst_data[index].Expenses[index3].ProjectPhaseExpensePeopleLst = phaseResouce_predicate_data
		}
	}

	result.Phases = phaselst_data

	return result, nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/ProjectService.UpdateOne
 *
 ******************************************************************************/
func (impl *ProjectServiceImplement) UpdateOne(user *global.User, entity *model.Project) error {

	grmi.Log(user, "/services/pj/implments/Project.service.impl.go", "UpdateOneProject", "修改一个Project")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewProjectDAO(session, user.UserId)
	record, err := dao.SelectOne(entity.ProjectId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/ProjectService.Insert
 *
 ******************************************************************************/
func (impl *ProjectServiceImplement) Insert(user *global.User, entities *[]model.Project) error {

	grmi.Log(user, "/services/pj/implments/Project.service.impl.go", "InsertProject", "插入多个Project")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewProjectDAO(session, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.ProjectId)
		if err != nil {
			return err
		}
		if record != nil {
			return grmi.NewBusinessError("已经存在相同主键的记录!")
		}
	}

	err := dao.Insert(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/ProjectService.Delete
 *
 ******************************************************************************/
func (impl *ProjectServiceImplement) Delete(user *global.User, entities *[]model.Project) error {

	grmi.Log(user, "/services/pj/implments/Project.service.impl.go", "DeleteProject", "删除多个Project")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewProjectDAO(session, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.ProjectId)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Delete(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/ProjectService.Select
 *
 ******************************************************************************/
func (impl *ProjectServiceImplement) Select(user *global.User, urlParameters map[string]string) ([]model.Project, error) {

	grmi.Log(user, "/services/pj/implments/Project.service.impl.go", "SelectProject", "查询Project")

	condition := DefaultConditionOfProjectAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewProjectDAO(session, user.UserId)
	result, err := dao.Select(predicates, condition.OrderByFields)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/ProjectService.SelectAndPaging
 *
 ******************************************************************************/
func (impl *ProjectServiceImplement) SelectAndPaging(user *global.User, urlParameters map[string]string) (grmi.PagingResult, error) {

	grmi.Log(user, "/services/pj/implments/Project.service.impl.go", "SelectProject", "查询Project")

	condition := DefaultConditionOfProjectAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	dao := dal.NewProjectDAO(session, user.UserId)
	condition.Fill(urlParameters)
	result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/ProjectService.Update
 *
 ******************************************************************************/
func (impl *ProjectServiceImplement) Update(user *global.User, entities *[]model.Project) error {

	grmi.Log(user, "/services/pj/implments/Project.service.impl.go", "UpdateProject", "修改多个Project")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewProjectDAO(session, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.ProjectId)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Update(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/ProjectService.Close
 *
 ******************************************************************************/
func (impl *ProjectServiceImplement) Close(user *global.User, ProjectId string) error {

	grmi.Log(user, "/services/pj/implments/Project.service.impl.go", "UpdateOneProject", "修改一个Project")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewProjectDAO(session, user.UserId)
	record, err := dao.SelectOne(ProjectId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	record.Status = 2
	err = dao.UpdateOne(record)
	if err != nil {
		return err
	}
	return nil
}

