// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	dal "LEIT_PM/dao/pj"
	"LEIT_PM/db"
	"LEIT_PM/global"
	"LEIT_PM/grmi"
	meta "LEIT_PM/meta/pj"
	model "LEIT_PM/models/pj"
	"LEIT_PM/utils"
	"strings"
)

/******************************************************************************
 *
 * @Description              : ProjectDocumentLst的默认查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-08 00:22:25
 *
 ******************************************************************************/
var DefaultConditionOfProjectDocumentLst = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.ProjectDocumentLst_ProjectId.UrlParameterName:    grmi.NewConditionItem(meta.ProjectDocumentLst_ProjectId, grmi.Equal, true),
		meta.ProjectDocumentLst_Pos.UrlParameterName:          grmi.NewConditionItem(meta.ProjectDocumentLst_Pos, grmi.Equal, true),
		meta.ProjectDocumentLst_Document.UrlParameterName:     grmi.NewConditionItem(meta.ProjectDocumentLst_Document, grmi.Equal, false),
		meta.ProjectDocumentLst_DocumentType.UrlParameterName: grmi.NewConditionItem(meta.ProjectDocumentLst_DocumentType, grmi.Equal, false),
		meta.ProjectDocumentLst_UploadTime.UrlParameterName:   grmi.NewConditionItem(meta.ProjectDocumentLst_UploadTime, grmi.Approximate, false),
		meta.ProjectDocumentLst_Remark.UrlParameterName:       grmi.NewConditionItem(meta.ProjectDocumentLst_Remark, grmi.Equal, false),
		meta.ProjectDocumentLst_CreateUser.UrlParameterName:   grmi.NewConditionItem(meta.ProjectDocumentLst_CreateUser, grmi.Equal, false),
		meta.ProjectDocumentLst_LastModify.UrlParameterName:   grmi.NewConditionItem(meta.ProjectDocumentLst_LastModify, grmi.Approximate, false),
		meta.ProjectDocumentLst_LastUser.UrlParameterName:     grmi.NewConditionItem(meta.ProjectDocumentLst_LastUser, grmi.Equal, false),
		meta.ProjectDocumentLst_CreateTime.UrlParameterName:   grmi.NewConditionItem(meta.ProjectDocumentLst_CreateTime, grmi.Approximate, false),
	},
	nil,
)

/******************************************************************************
 *
 * @Description              : ProjectDocumentLst的默认分页查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-08 00:22:25
 *
 ******************************************************************************/
var DefaultConditionOfProjectDocumentLstAndPaging = grmi.NewCondition(
	DefaultConditionOfProjectDocumentLst.Items,
	grmi.NewPaging(),
)

/******************************************************************************
 *
 * @Struct Name              : ProjectDocumentLstServiceImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : ProjectDocumentLst的服务实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-08 00:22:25
 *
 ******************************************************************************/
type ProjectDocumentLstServiceImplement struct {
}

/******************************************************************************
 *
 * @Function Name            : NewProjectDocumentLstDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个ProjectDocumentLstDAOImplement实例
 *
 * @Return Value             : ProjectDocumentLstDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-08 00:22:25
 *
 ******************************************************************************/
func NewProjectDocumentLstServiceImplement() *ProjectDocumentLstServiceImplement {
	return &ProjectDocumentLstServiceImplement{}
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/ProjectDocumentLstService.InsertOne
 *
 ******************************************************************************/
func (impl *ProjectDocumentLstServiceImplement) InsertOne(user *global.User, entity *model.ProjectDocumentLst) error {

	grmi.Log(user, "/services/pj/implments/ProjectDocumentLst.service.impl.go", "InsertOneProjectDocumentLst", "插入一个ProjectDocumentLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewProjectDocumentLstDAO(session, user.UserId)
	record, err := dao.SelectOne(entity.ProjectId, entity.Pos)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/ProjectDocumentLstService.DeleteOne
 *
 ******************************************************************************/
func (impl *ProjectDocumentLstServiceImplement) DeleteOne(user *global.User, projectId string, pos int) error {

	grmi.Log(user, "/services/pj/implments/ProjectDocumentLst.service.impl.go", "DeleteOneProjectDocumentLst", "删除一个ProjectDocumentLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewProjectDocumentLstDAO(session, user.UserId)
	record, err := dao.SelectOne(projectId, pos)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(projectId, pos)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/ProjectDocumentLstService.SelectOne
 *
 ******************************************************************************/
func (impl *ProjectDocumentLstServiceImplement) SelectOne(user *global.User, projectId string, pos int) (*model.ProjectDocumentLst, error) {

	grmi.Log(user, "/services/pj/implments/ProjectDocumentLst.service.impl.go", "SelectOneProjectDocumentLst", "查询一个ProjectDocumentLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewProjectDocumentLstDAO(session, user.UserId)
	result, err := dao.SelectOne(projectId, pos)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/ProjectDocumentLstService.UpdateOne
 *
 ******************************************************************************/
func (impl *ProjectDocumentLstServiceImplement) UpdateOne(user *global.User, entity *model.ProjectDocumentLst) error {

	grmi.Log(user, "/services/pj/implments/ProjectDocumentLst.service.impl.go", "UpdateOneProjectDocumentLst", "修改一个ProjectDocumentLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewProjectDocumentLstDAO(session, user.UserId)
	record, err := dao.SelectOne(entity.ProjectId, entity.Pos)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/ProjectDocumentLstService.Insert
 *
 ******************************************************************************/
func (impl *ProjectDocumentLstServiceImplement) Insert(user *global.User, entities *[]model.ProjectDocumentLst) error {

	grmi.Log(user, "/services/pj/implments/ProjectDocumentLst.service.impl.go", "InsertProjectDocumentLst", "插入多个ProjectDocumentLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewProjectDocumentLstDAO(session, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.ProjectId, entity.Pos)
		if err != nil {
			return err
		}
		if record != nil {
			return grmi.NewBusinessError("已经存在相同主键的记录!")
		}
	}

	err := dao.Insert(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/ProjectDocumentLstService.Delete
 *
 ******************************************************************************/
func (impl *ProjectDocumentLstServiceImplement) Delete(user *global.User, entities *[]model.ProjectDocumentLst) error {

	grmi.Log(user, "/services/pj/implments/ProjectDocumentLst.service.impl.go", "DeleteProjectDocumentLst", "删除多个ProjectDocumentLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewProjectDocumentLstDAO(session, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.ProjectId, entity.Pos)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Delete(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/ProjectDocumentLstService.Select
 *
 ******************************************************************************/
func (impl *ProjectDocumentLstServiceImplement) Select(user *global.User, urlParameters map[string]string) ([]model.ProjectDocumentLst, error) {

	grmi.Log(user, "/services/pj/implments/ProjectDocumentLst.service.impl.go", "SelectProjectDocumentLst", "查询ProjectDocumentLst")

	condition := DefaultConditionOfProjectDocumentLstAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewProjectDocumentLstDAO(session, user.UserId)
	result, err := dao.Select(predicates, condition.OrderByFields)
	if err != nil {
		return nil, err
	}

	for index, data := range result{
		record, err := dao.SelectOne(data.ProjectId, data.Pos)
		if err != nil {
			return nil,err
		}
		if record == nil {
			return nil,grmi.NewBusinessError("找不到文件")
		}

		dirname, err := utils.GetCurrentPath("web/public")
		if err != nil {
			return nil, grmi.NewBusinessError("文件夹找不到， 错误：" + err.Error())
		}

		filepath := dirname + "/" +record.ProjectId + "/"+ record.Document+"."+record.DocumentType

		pathLi := strings.Split(filepath, "web\\")
		if len(pathLi) != 2 {
			return nil, grmi.NewBusinessError("文档损坏")
		}

		result[index].Url = pathLi[1]
	}


	return result, nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/ProjectDocumentLstService.SelectAndPaging
 *
 ******************************************************************************/
func (impl *ProjectDocumentLstServiceImplement) SelectAndPaging(user *global.User, urlParameters map[string]string) (grmi.PagingResult, error) {

	grmi.Log(user, "/services/pj/implments/ProjectDocumentLst.service.impl.go", "SelectProjectDocumentLst", "查询ProjectDocumentLst")

	condition := DefaultConditionOfProjectDocumentLstAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	dao := dal.NewProjectDocumentLstDAO(session, user.UserId)
	condition.Fill(urlParameters)
	result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/ProjectDocumentLstService.Update
 *
 ******************************************************************************/
func (impl *ProjectDocumentLstServiceImplement) Update(user *global.User, entities *[]model.ProjectDocumentLst) error {

	grmi.Log(user, "/services/pj/implments/ProjectDocumentLst.service.impl.go", "UpdateProjectDocumentLst", "修改多个ProjectDocumentLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewProjectDocumentLstDAO(session, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.ProjectId, entity.Pos)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Update(entities)
	if err != nil {
		return err
	}
	return nil
}

func (impl *ProjectDocumentLstServiceImplement) Upload(user *global.User, entity *model.ProjectDocumentLst) (result []model.ProjectDocumentLst, err error) {
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewProjectDocumentLstDAO(session, user.UserId)
	dataSlice, err := dao.Select([]grmi.Predicate{},[]grmi.Field{meta.ProjectDocumentLst_Pos})
	if err != nil {
		return nil,err
	}
	if len(dataSlice) == 0{
		entity.Pos = 1
	}else{
		entity.Pos = dataSlice[len(dataSlice)-1].Pos + 1
	}

	record, err := dao.SelectOne(entity.ProjectId, entity.Pos)
	if err != nil {
		return nil,err
	}
	if record != nil {
		return nil,grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return nil,err
	}


	result, err = dao.Select(nil,nil)
	if err != nil {
		return nil, err
	}

	return result, err
}

func (impl *ProjectDocumentLstServiceImplement)Download(user *global.User,projectId string,pos int) (result string, err error){
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewProjectDocumentLstDAO(session, user.UserId)
	record, err := dao.SelectOne(projectId, pos)
	if err != nil {
		return "",err
	}
	if record == nil {
		return "",grmi.NewBusinessError("找不到文件")
	}

	dirname, err := utils.GetCurrentPath("web/public/uploadxlsx")
	if err != nil {
		return "", grmi.NewBusinessError("文件夹找不到， 错误：" + err.Error())
	}

	filepath := dirname + "/" + record.Document+"."+record.DocumentType

	pathLi := strings.Split(filepath, "web\\")
	if len(pathLi) != 2 {
		return "", grmi.NewBusinessError("文档损坏")
	}
	return pathLi[1], nil
}