// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	dal "LEIT_PM/dao/pj"
	"LEIT_PM/db"
	"LEIT_PM/global"
	"LEIT_PM/grmi"
	meta "LEIT_PM/meta/pj"
	model "LEIT_PM/models/pj"
)

/******************************************************************************
 *
 * @Description              : Resource的默认查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-09 13:42:59
 *
 ******************************************************************************/
var DefaultConditionOfResource = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.Resource_ResourceId.UrlParameterName:   grmi.NewConditionItem(meta.Resource_ResourceId, grmi.Equal, true),
		meta.Resource_Descr.UrlParameterName:        grmi.NewConditionItem(meta.Resource_Descr, grmi.Equal, false),
		meta.Resource_ResourceType.UrlParameterName: grmi.NewConditionItem(meta.Resource_ResourceType, grmi.Equal, false),
		meta.Resource_SkillLevel.UrlParameterName:   grmi.NewConditionItem(meta.Resource_SkillLevel, grmi.Equal, false),
		meta.Resource_MandayRate.UrlParameterName:   grmi.NewConditionItem(meta.Resource_MandayRate, grmi.Equal, false),
		meta.Resource_Status.UrlParameterName:       grmi.NewConditionItem(meta.Resource_Status, grmi.Equal, false),
		meta.Resource_CtrlPara1.UrlParameterName:    grmi.NewConditionItem(meta.Resource_CtrlPara1, grmi.Equal, false),
		meta.Resource_CtrlPara2.UrlParameterName:    grmi.NewConditionItem(meta.Resource_CtrlPara2, grmi.Equal, false),
		meta.Resource_CtrlStr1.UrlParameterName:     grmi.NewConditionItem(meta.Resource_CtrlStr1, grmi.Equal, false),
		meta.Resource_CtrlStr2.UrlParameterName:     grmi.NewConditionItem(meta.Resource_CtrlStr2, grmi.Equal, false),
		meta.Resource_CtrlTime1.UrlParameterName:    grmi.NewConditionItem(meta.Resource_CtrlTime1, grmi.Approximate, false),
		meta.Resource_CtrlTime2.UrlParameterName:    grmi.NewConditionItem(meta.Resource_CtrlTime2, grmi.Approximate, false),
		meta.Resource_LastModify.UrlParameterName:   grmi.NewConditionItem(meta.Resource_LastModify, grmi.Approximate, false),
		meta.Resource_LastUser.UrlParameterName:     grmi.NewConditionItem(meta.Resource_LastUser, grmi.Equal, false),
		meta.Resource_CreateTime.UrlParameterName:   grmi.NewConditionItem(meta.Resource_CreateTime, grmi.Approximate, false),
	},
	nil,
)

/******************************************************************************
 *
 * @Description              : Resource的默认分页查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
var DefaultConditionOfResourceAndPaging = grmi.NewCondition(
	DefaultConditionOfResource.Items,
	grmi.NewPaging(),
)

/******************************************************************************
 *
 * @Struct Name              : ResourceServiceImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : Resource的服务实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
type ResourceServiceImplement struct {
}

/******************************************************************************
 *
 * @Function Name            : NewResourceDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个ResourceDAOImplement实例
 *
 * @Return Value             : ResourceDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func NewResourceServiceImplement() *ResourceServiceImplement {
	return &ResourceServiceImplement{}
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/ResourceService.InsertOne
 *
 ******************************************************************************/
func (impl *ResourceServiceImplement) InsertOne(user *global.User, entity *model.Resource) error {

	grmi.Log(user, "/services/pj/implments/Resource.service.impl.go", "InsertOneResource", "插入一个Resource")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewResourceDAO(session, user.UserId)
	record, err := dao.SelectOne(entity.ResourceId)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/ResourceService.DeleteOne
 *
 ******************************************************************************/
func (impl *ResourceServiceImplement) DeleteOne(user *global.User, resourceId string) error {

	grmi.Log(user, "/services/pj/implments/Resource.service.impl.go", "DeleteOneResource", "删除一个Resource")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewResourceDAO(session, user.UserId)
	record, err := dao.SelectOne(resourceId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(resourceId)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/ResourceService.SelectOne
 *
 ******************************************************************************/
func (impl *ResourceServiceImplement) SelectOne(user *global.User, resourceId string) (*model.Resource, error) {

	grmi.Log(user, "/services/pj/implments/Resource.service.impl.go", "SelectOneResource", "查询一个Resource")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewResourceDAO(session, user.UserId)
	result, err := dao.SelectOne(resourceId)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/ResourceService.UpdateOne
 *
 ******************************************************************************/
func (impl *ResourceServiceImplement) UpdateOne(user *global.User, entity *model.Resource) error {

	grmi.Log(user, "/services/pj/implments/Resource.service.impl.go", "UpdateOneResource", "修改一个Resource")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewResourceDAO(session, user.UserId)
	record, err := dao.SelectOne(entity.ResourceId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/ResourceService.Insert
 *
 ******************************************************************************/
func (impl *ResourceServiceImplement) Insert(user *global.User, entities *[]model.Resource) error {

	grmi.Log(user, "/services/pj/implments/Resource.service.impl.go", "InsertResource", "插入多个Resource")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewResourceDAO(session, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.ResourceId)
		if err != nil {
			return err
		}
		if record != nil {
			return grmi.NewBusinessError("已经存在相同主键的记录!")
		}
	}

	err := dao.Insert(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/ResourceService.Delete
 *
 ******************************************************************************/
func (impl *ResourceServiceImplement) Delete(user *global.User, entities *[]model.Resource) error {

	grmi.Log(user, "/services/pj/implments/Resource.service.impl.go", "DeleteResource", "删除多个Resource")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewResourceDAO(session, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.ResourceId)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Delete(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/ResourceService.Select
 *
 ******************************************************************************/
func (impl *ResourceServiceImplement) Select(user *global.User, urlParameters map[string]string) ([]model.Resource, error) {

	grmi.Log(user, "/services/pj/implments/Resource.service.impl.go", "SelectResource", "查询Resource")

	condition := DefaultConditionOfResourceAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewResourceDAO(session, user.UserId)
	result, err := dao.Select(predicates, condition.OrderByFields)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/ResourceService.SelectAndPaging
 *
 ******************************************************************************/
func (impl *ResourceServiceImplement) SelectAndPaging(user *global.User, urlParameters map[string]string) (grmi.PagingResult, error) {

	grmi.Log(user, "/services/pj/implments/Resource.service.impl.go", "SelectResource", "查询Resource")

	condition := DefaultConditionOfResourceAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	dao := dal.NewResourceDAO(session, user.UserId)
	condition.Fill(urlParameters)
	result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/ResourceService.Update
 *
 ******************************************************************************/
func (impl *ResourceServiceImplement) Update(user *global.User, entities *[]model.Resource) error {

	grmi.Log(user, "/services/pj/implments/Resource.service.impl.go", "UpdateResource", "修改多个Resource")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewResourceDAO(session, user.UserId)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.ResourceId)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Update(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/ResourceService.Enable
 *
 ******************************************************************************/
func (impl *ResourceServiceImplement) Enable(user *global.User, resourceId string) error {

	grmi.Log(user, "/services/pj/implments/Resource.service.impl.go", "EnableResource", "启动Resource")


	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewResourceDAO(session, user.UserId)
	result, err := dao.SelectOne(resourceId)
	if err != nil {
		return err
	}
	//启用资源
	result.Status = 1
	err = dao.UpdateOne(result)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LEIT_PM/services/pj/ResourceService.Disable
 *
 ******************************************************************************/
func (impl *ResourceServiceImplement) Disable(user *global.User, resourceId string) error {

	grmi.Log(user, "/services/pj/implments/Resource.service.impl.go", "EnableResource", "启动Resource")


	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewResourceDAO(session, user.UserId)
	result, err := dao.SelectOne(resourceId)
	if err != nil {
		return err
	}
	//停用资源
	result.Status = 2
	err = dao.UpdateOne(result)
	if err != nil {
		return err
	}
	return nil
}

