// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
	"LEIT_PM/global"
	"LEIT_PM/grmi"
	model "LEIT_PM/models/base"
	"LEIT_PM/web/middleware/jwts"
	"LEIT_PM/web/supports"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneCostCenter
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条CostCenter的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 11:11:05
 *
 ******************************************************************************/
func RegisterOneCostCenter(party router.Party, httpMethod string, path string, method func(*global.User, *model.CostCenter) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.CostCenter)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfCostCenter
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条CostCenter的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 11:11:05
 *
 ******************************************************************************/
func RegisterIDOfCostCenter(party router.Party, httpMethod string, path string, method func(*global.User, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		costCenterId := ctx.Params().GetString("costCenterId")

		err = method(user, costCenterId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneCostCenter
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条CostCenter的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 11:11:05
 *
 ******************************************************************************/
func RegisterInsertOneCostCenter(party router.Party, path string, method func(*global.User, *model.CostCenter) error) {

	RegisterOneCostCenter(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneCostCenter
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条CostCenter的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 11:11:05
 *
 ******************************************************************************/
func RegisterDeleteOneCostCenter(party router.Party, path string, method func(*global.User, string) error) {

	RegisterIDOfCostCenter(party, "DELETE", path+"/{costCenterId:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneCostCenter
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条CostCenter的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 11:11:05
 *
 ******************************************************************************/
func RegisterSelectOneCostCenter(party router.Party, path string, method func(*global.User, string) (*model.CostCenter, error)) {

	party.Get(path+"/{costCenterId:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		costCenterId := ctx.Params().GetString("costCenterId")
		result, err := method(user, costCenterId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneCostCenter
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条CostCenter的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 11:11:05
 *
 ******************************************************************************/
func RegisterUpdateOneCostCenter(party router.Party, path string, method func(*global.User, *model.CostCenter) error) {

	RegisterOneCostCenter(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiCostCenter
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条CostCenter的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 11:11:05
 *
 ******************************************************************************/
func RegisterMultiCostCenter(party router.Party, httpMethod string, path string, method func(*global.User, *[]model.CostCenter) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.CostCenter, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertCostCenter
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条CostCenter的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 11:11:05
 *
 ******************************************************************************/
func RegisterInsertCostCenter(party router.Party, path string, method func(*global.User, *[]model.CostCenter) error) {

	RegisterMultiCostCenter(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteCostCenter
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条CostCenter的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 11:11:05
 *
 ******************************************************************************/
func RegisterDeleteCostCenter(party router.Party, path string, method func(*global.User, *[]model.CostCenter) error) {

	RegisterMultiCostCenter(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectCostCenter
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询CostCenter的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 11:11:05
 *
 ******************************************************************************/
func RegisterSelectCostCenter(party router.Party, path string, method func(*global.User, map[string]string) ([]model.CostCenter, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterQueryCostCenter
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询CostCenter并分页的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 11:11:05
 *
 ******************************************************************************/
func RegisterQueryCostCenter(party router.Party, path string, method func(*global.User, map[string]string) (grmi.PagingResult, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateCostCenter
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条CostCenter的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 11:11:05
 *
 ******************************************************************************/
func RegisterUpdateCostCenter(party router.Party, path string, method func(*global.User, *[]model.CostCenter) error) {

	RegisterMultiCostCenter(party, "PUT", path, method)
}
