// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package pj

import (
	"LEIT_PM/global"
	"LEIT_PM/grmi"
	model "LEIT_PM/models/pj"
	"LEIT_PM/web/middleware/jwts"
	"LEIT_PM/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneExpenseType
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条ExpenseType的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-09 13:38:13
 *
 ******************************************************************************/
func RegisterOneExpenseType(party router.Party, httpMethod string, path string, method func(*global.User, *model.ExpenseType) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.ExpenseType)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfExpenseType
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条ExpenseType的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-09 13:38:13
 *
 ******************************************************************************/
func RegisterIDOfExpenseType(party router.Party, httpMethod string, path string, method func(*global.User, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		expenseTypeId := ctx.Params().GetString("expenseTypeId")

		err = method(user, expenseTypeId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneExpenseType
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条ExpenseType的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-09 13:38:13
 *
 ******************************************************************************/
func RegisterInsertOneExpenseType(party router.Party, path string, method func(*global.User, *model.ExpenseType) error) {

	RegisterOneExpenseType(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneExpenseType
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条ExpenseType的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-09 13:38:13
 *
 ******************************************************************************/
func RegisterDeleteOneExpenseType(party router.Party, path string, method func(*global.User, string) error) {

	RegisterIDOfExpenseType(party, "DELETE", path+"/{expenseTypeId:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneExpenseType
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条ExpenseType的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-09 13:38:13
 *
 ******************************************************************************/
func RegisterSelectOneExpenseType(party router.Party, path string, method func(*global.User, string) (*model.ExpenseType, error)) {

	party.Get(path+"/{expenseTypeId:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		expenseTypeId := ctx.Params().GetString("expenseTypeId")
		result, err := method(user, expenseTypeId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneExpenseType
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条ExpenseType的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-09 13:38:13
 *
 ******************************************************************************/
func RegisterUpdateOneExpenseType(party router.Party, path string, method func(*global.User, *model.ExpenseType) error) {

	RegisterOneExpenseType(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiExpenseType
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条ExpenseType的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-09 13:38:13
 *
 ******************************************************************************/
func RegisterMultiExpenseType(party router.Party, httpMethod string, path string, method func(*global.User, *[]model.ExpenseType) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.ExpenseType, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertExpenseType
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条ExpenseType的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-09 13:38:13
 *
 ******************************************************************************/
func RegisterInsertExpenseType(party router.Party, path string, method func(*global.User, *[]model.ExpenseType) error) {

	RegisterMultiExpenseType(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteExpenseType
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条ExpenseType的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-09 13:38:13
 *
 ******************************************************************************/
func RegisterDeleteExpenseType(party router.Party, path string, method func(*global.User, *[]model.ExpenseType) error) {

	RegisterMultiExpenseType(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectExpenseType
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ExpenseType的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-09 13:38:13
 *
 ******************************************************************************/
func RegisterSelectExpenseType(party router.Party, path string, method func(*global.User, map[string]string) ([]model.ExpenseType, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterQueryExpenseType
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ExpenseType并分页的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-09 13:38:13
 *
 ******************************************************************************/
func RegisterQueryExpenseType(party router.Party, path string, method func(*global.User, map[string]string) (grmi.PagingResult, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateExpenseType
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条ExpenseType的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-09 13:38:13
 *
 ******************************************************************************/
func RegisterUpdateExpenseType(party router.Party, path string, method func(*global.User, *[]model.ExpenseType) error) {

	RegisterMultiExpenseType(party, "PUT", path, method)
}
