// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package pj

import (
	"LEIT_PM/global"
	"LEIT_PM/grmi"
	model "LEIT_PM/models/pj"
	"LEIT_PM/web/middleware/jwts"
	"LEIT_PM/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOnePeople
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条People的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-08 00:22:25
 *
 ******************************************************************************/
func RegisterOnePeople(party router.Party, httpMethod string, path string, method func(*global.User, *model.People) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.People)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfPeople
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条People的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-08 00:22:25
 *
 ******************************************************************************/
func RegisterIDOfPeople(party router.Party, httpMethod string, path string, method func(*global.User, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		name := ctx.Params().GetString("name")

		err = method(user, name)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOnePeople
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条People的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-08 00:22:25
 *
 ******************************************************************************/
func RegisterInsertOnePeople(party router.Party, path string, method func(*global.User, *model.People) error) {

	RegisterOnePeople(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOnePeople
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条People的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-08 00:22:25
 *
 ******************************************************************************/
func RegisterDeleteOnePeople(party router.Party, path string, method func(*global.User, string) error) {

	RegisterIDOfPeople(party, "DELETE", path+"/{name:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOnePeople
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条People的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-08 00:22:25
 *
 ******************************************************************************/
func RegisterSelectOnePeople(party router.Party, path string, method func(*global.User, string) (*model.People, error)) {

	party.Get(path+"/{name:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		name := ctx.Params().GetString("name")
		result, err := method(user, name)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOnePeople
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条People的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-08 00:22:25
 *
 ******************************************************************************/
func RegisterUpdateOnePeople(party router.Party, path string, method func(*global.User, *model.People) error) {

	RegisterOnePeople(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiPeople
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条People的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-08 00:22:25
 *
 ******************************************************************************/
func RegisterMultiPeople(party router.Party, httpMethod string, path string, method func(*global.User, *[]model.People) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.People, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertPeople
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条People的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-08 00:22:25
 *
 ******************************************************************************/
func RegisterInsertPeople(party router.Party, path string, method func(*global.User, *[]model.People) error) {

	RegisterMultiPeople(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeletePeople
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条People的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-08 00:22:25
 *
 ******************************************************************************/
func RegisterDeletePeople(party router.Party, path string, method func(*global.User, *[]model.People) error) {

	RegisterMultiPeople(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectPeople
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询People的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-08 00:22:25
 *
 ******************************************************************************/
func RegisterSelectPeople(party router.Party, path string, method func(*global.User, map[string]string) ([]model.People, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterQueryPeople
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询People并分页的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-08 00:22:25
 *
 ******************************************************************************/
func RegisterQueryPeople(party router.Party, path string, method func(*global.User, map[string]string) (grmi.PagingResult, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdatePeople
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条People的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-08 00:22:25
 *
 ******************************************************************************/
func RegisterUpdatePeople(party router.Party, path string, method func(*global.User, *[]model.People) error) {

	RegisterMultiPeople(party, "PUT", path, method)
}
