// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package pj

import (
	"LEIT_PM/global"
	"LEIT_PM/grmi"
	model "LEIT_PM/models/pj"
	"LEIT_PM/utils"
	"LEIT_PM/web/middleware/jwts"
	"LEIT_PM/web/supports"
	json "github.com/json-iterator/go"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
	"os"
	"path/filepath"
	"strings"
	"time"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneProjectDocumentLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条ProjectDocumentLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-08 00:22:25
 *
 ******************************************************************************/
func RegisterOneProjectDocumentLst(party router.Party, httpMethod string, path string, method func(*global.User, *model.ProjectDocumentLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.ProjectDocumentLst)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfProjectDocumentLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条ProjectDocumentLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-08 00:22:25
 *
 ******************************************************************************/
func RegisterIDOfProjectDocumentLst(party router.Party, httpMethod string, path string, method func(*global.User, string, int) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		projectId := ctx.Params().GetString("projectId")
		pos, err := ctx.Params().GetInt("pos")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, projectId, pos)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneProjectDocumentLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条ProjectDocumentLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-08 00:22:25
 *
 ******************************************************************************/
func RegisterInsertOneProjectDocumentLst(party router.Party, path string, method func(*global.User, *model.ProjectDocumentLst) error) {

	RegisterOneProjectDocumentLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneProjectDocumentLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条ProjectDocumentLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-08 00:22:25
 *
 ******************************************************************************/
func RegisterDeleteOneProjectDocumentLst(party router.Party, path string, method func(*global.User, string, int) error) {

	RegisterIDOfProjectDocumentLst(party, "DELETE", path+"/{projectId:string}/{pos:int}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneProjectDocumentLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条ProjectDocumentLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-08 00:22:25
 *
 ******************************************************************************/
func RegisterSelectOneProjectDocumentLst(party router.Party, path string, method func(*global.User, string, int) (*model.ProjectDocumentLst, error)) {

	party.Get(path+"/{projectId:string}/{pos:int}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		projectId := ctx.Params().GetString("projectId")
		pos, err := ctx.Params().GetInt("pos")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		result, err := method(user, projectId, pos)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneProjectDocumentLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条ProjectDocumentLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-08 00:22:25
 *
 ******************************************************************************/
func RegisterUpdateOneProjectDocumentLst(party router.Party, path string, method func(*global.User, *model.ProjectDocumentLst) error) {

	RegisterOneProjectDocumentLst(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiProjectDocumentLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条ProjectDocumentLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-08 00:22:25
 *
 ******************************************************************************/
func RegisterMultiProjectDocumentLst(party router.Party, httpMethod string, path string, method func(*global.User, *[]model.ProjectDocumentLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.ProjectDocumentLst, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertProjectDocumentLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条ProjectDocumentLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-08 00:22:25
 *
 ******************************************************************************/
func RegisterInsertProjectDocumentLst(party router.Party, path string, method func(*global.User, *[]model.ProjectDocumentLst) error) {

	RegisterMultiProjectDocumentLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteProjectDocumentLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条ProjectDocumentLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-08 00:22:25
 *
 ******************************************************************************/
func RegisterDeleteProjectDocumentLst(party router.Party, path string, method func(*global.User, *[]model.ProjectDocumentLst) error) {

	RegisterMultiProjectDocumentLst(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectProjectDocumentLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ProjectDocumentLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-08 00:22:25
 *
 ******************************************************************************/
func RegisterSelectProjectDocumentLst(party router.Party, path string, method func(*global.User, map[string]string) ([]model.ProjectDocumentLst, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterQueryProjectDocumentLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ProjectDocumentLst并分页的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-08 00:22:25
 *
 ******************************************************************************/
func RegisterQueryProjectDocumentLst(party router.Party, path string, method func(*global.User, map[string]string) (grmi.PagingResult, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateProjectDocumentLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条ProjectDocumentLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-08 00:22:25
 *
 ******************************************************************************/
func RegisterUpdateProjectDocumentLst(party router.Party, path string, method func(*global.User, *[]model.ProjectDocumentLst) error) {

	RegisterMultiProjectDocumentLst(party, "PUT", path, method)
}


func RegisterUploadProjectDocumentLst(party router.Party, path string, method func(*global.User,*model.ProjectDocumentLst) ([]model.ProjectDocumentLst, error)) {

	party.Post(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			return
		}

		entity := new(model.ProjectDocumentLst)
		info := ctx.FormValue("data")
		if info != "" {
			err := json.Unmarshal([]byte(info), &entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, "json解析错误:"+err.Error(), nil)
				return
			}
		}

		//获取通过iris.WithPostMaxMemory获取的最大上传值大小。
		maxSize := ctx.Application().ConfigurationReadOnly().GetPostMaxMemory()
		err := ctx.Request().ParseMultipartForm(maxSize)
		if err != nil {
			ctx.StatusCode(iris.StatusInternalServerError)
			ctx.WriteString(err.Error())
			return
		}
		form := ctx.Request().MultipartForm
		files := form.File["upload"]

		savePath := ""
		file := files[0]
		//for _, file := range files {
			if !utils.ValueIsEmpty(file.Filename) {
				savePath = "./web/public/"
				// 必须分成两步：先创建文件夹、再修改权限
				folderPath := filepath.Join(savePath, entity.ProjectId)
				if _, err := os.Stat(folderPath); os.IsNotExist(err) {
					// 必须分成两步：先创建文件夹、再修改权限
					os.Mkdir(folderPath, 0777) //0777也可以os.ModePerm
					os.Chmod(folderPath, 0777)
				}

				// 上传文件至指定目录
				err = utils.SaveUploadedFile(file, folderPath+ "/"+file.Filename)
				if err != nil {
					supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
					return
				}
				//break
				dList := strings.Split(file.Filename,".")
				entity.Document =dList[0]
				entity.DocumentType = dList[1]
				entity.UploadTime = grmi.DateTime(time.Now())
			}
		//}
		result, err := method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}
