// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package pj

import (
	"LEIT_PM/global"
	"LEIT_PM/grmi"
	model "LEIT_PM/models/pj"
	"LEIT_PM/web/middleware/jwts"
	"LEIT_PM/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneProjectPaymentPhaseLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条ProjectPaymentPhaseLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterOneProjectPaymentPhaseLst(party router.Party, httpMethod string, path string, method func(*global.User, *model.ProjectPaymentPhaseLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.ProjectPaymentPhaseLst)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfProjectPaymentPhaseLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条ProjectPaymentPhaseLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterIDOfProjectPaymentPhaseLst(party router.Party, httpMethod string, path string, method func(*global.User, string, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		projectId := ctx.Params().GetString("projectId")
		paymentPhaseId := ctx.Params().GetString("paymentPhaseId")

		err = method(user, projectId, paymentPhaseId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneProjectPaymentPhaseLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条ProjectPaymentPhaseLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterInsertOneProjectPaymentPhaseLst(party router.Party, path string, method func(*global.User, *model.ProjectPaymentPhaseLst) error) {

	RegisterOneProjectPaymentPhaseLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneProjectPaymentPhaseLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条ProjectPaymentPhaseLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterDeleteOneProjectPaymentPhaseLst(party router.Party, path string, method func(*global.User, string, string) error) {

	RegisterIDOfProjectPaymentPhaseLst(party, "DELETE", path+"/{projectId:string}/{paymentPhaseId:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneProjectPaymentPhaseLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条ProjectPaymentPhaseLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterSelectOneProjectPaymentPhaseLst(party router.Party, path string, method func(*global.User, string, string) (*model.ProjectPaymentPhaseLst, error)) {

	party.Get(path+"/{projectId:string}/{paymentPhaseId:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		projectId := ctx.Params().GetString("projectId")
		paymentPhaseId := ctx.Params().GetString("paymentPhaseId")
		result, err := method(user, projectId, paymentPhaseId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneProjectPaymentPhaseLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条ProjectPaymentPhaseLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterUpdateOneProjectPaymentPhaseLst(party router.Party, path string, method func(*global.User, *model.ProjectPaymentPhaseLst) error) {

	RegisterOneProjectPaymentPhaseLst(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiProjectPaymentPhaseLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条ProjectPaymentPhaseLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterMultiProjectPaymentPhaseLst(party router.Party, httpMethod string, path string, method func(*global.User, *[]model.ProjectPaymentPhaseLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.ProjectPaymentPhaseLst, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertProjectPaymentPhaseLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条ProjectPaymentPhaseLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterInsertProjectPaymentPhaseLst(party router.Party, path string, method func(*global.User, *[]model.ProjectPaymentPhaseLst) error) {

	RegisterMultiProjectPaymentPhaseLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteProjectPaymentPhaseLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条ProjectPaymentPhaseLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterDeleteProjectPaymentPhaseLst(party router.Party, path string, method func(*global.User, *[]model.ProjectPaymentPhaseLst) error) {

	RegisterMultiProjectPaymentPhaseLst(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectProjectPaymentPhaseLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ProjectPaymentPhaseLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterSelectProjectPaymentPhaseLst(party router.Party, path string, method func(*global.User, map[string]string) ([]model.ProjectPaymentPhaseLst, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterQueryProjectPaymentPhaseLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ProjectPaymentPhaseLst并分页的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterQueryProjectPaymentPhaseLst(party router.Party, path string, method func(*global.User, map[string]string) (grmi.PagingResult, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateProjectPaymentPhaseLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条ProjectPaymentPhaseLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterUpdateProjectPaymentPhaseLst(party router.Party, path string, method func(*global.User, *[]model.ProjectPaymentPhaseLst) error) {

	RegisterMultiProjectPaymentPhaseLst(party, "PUT", path, method)
}
