// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package pj

import (
	"LEIT_PM/global"
	"LEIT_PM/grmi"
	model "LEIT_PM/models/pj"
	"LEIT_PM/web/middleware/jwts"
	"LEIT_PM/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneProjectPhaseExpenseLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条ProjectPhaseExpenseLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterOneProjectPhaseExpenseLst(party router.Party, httpMethod string, path string, method func(*global.User, *model.ProjectPhaseExpenseLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.ProjectPhaseExpenseLst)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfProjectPhaseExpenseLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条ProjectPhaseExpenseLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterIDOfProjectPhaseExpenseLst(party router.Party, httpMethod string, path string, method func(*global.User, string, string, int) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		projectId := ctx.Params().GetString("projectId")
		phaseId := ctx.Params().GetString("phaseId")
		pos, err := ctx.Params().GetInt("pos")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, projectId, phaseId, pos)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneProjectPhaseExpenseLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条ProjectPhaseExpenseLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterInsertOneProjectPhaseExpenseLst(party router.Party, path string, method func(*global.User, *model.ProjectPhaseExpenseLst) error) {

	RegisterOneProjectPhaseExpenseLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneProjectPhaseExpenseLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条ProjectPhaseExpenseLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterDeleteOneProjectPhaseExpenseLst(party router.Party, path string, method func(*global.User, string, string, int) error) {

	RegisterIDOfProjectPhaseExpenseLst(party, "DELETE", path+"/{projectId:string}/{phaseId:string}/{pos:int}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneProjectPhaseExpenseLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条ProjectPhaseExpenseLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterSelectOneProjectPhaseExpenseLst(party router.Party, path string, method func(*global.User, string, string, int) (*model.ProjectPhaseExpenseLst, error)) {

	party.Get(path+"/{projectId:string}/{phaseId:string}/{pos:int}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		projectId := ctx.Params().GetString("projectId")
		phaseId := ctx.Params().GetString("phaseId")
		pos, err := ctx.Params().GetInt("pos")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		result, err := method(user, projectId, phaseId, pos)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneProjectPhaseExpenseLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条ProjectPhaseExpenseLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterUpdateOneProjectPhaseExpenseLst(party router.Party, path string, method func(*global.User, *model.ProjectPhaseExpenseLst) error) {

	RegisterOneProjectPhaseExpenseLst(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiProjectPhaseExpenseLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条ProjectPhaseExpenseLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterMultiProjectPhaseExpenseLst(party router.Party, httpMethod string, path string, method func(*global.User, *[]model.ProjectPhaseExpenseLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.ProjectPhaseExpenseLst, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertProjectPhaseExpenseLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条ProjectPhaseExpenseLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterInsertProjectPhaseExpenseLst(party router.Party, path string, method func(*global.User, *[]model.ProjectPhaseExpenseLst) error) {

	RegisterMultiProjectPhaseExpenseLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteProjectPhaseExpenseLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条ProjectPhaseExpenseLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterDeleteProjectPhaseExpenseLst(party router.Party, path string, method func(*global.User, *[]model.ProjectPhaseExpenseLst) error) {

	RegisterMultiProjectPhaseExpenseLst(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectProjectPhaseExpenseLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ProjectPhaseExpenseLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterSelectProjectPhaseExpenseLst(party router.Party, path string, method func(*global.User, map[string]string) ([]model.ProjectPhaseExpenseLst, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterQueryProjectPhaseExpenseLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ProjectPhaseExpenseLst并分页的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterQueryProjectPhaseExpenseLst(party router.Party, path string, method func(*global.User, map[string]string) (grmi.PagingResult, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateProjectPhaseExpenseLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条ProjectPhaseExpenseLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterUpdateProjectPhaseExpenseLst(party router.Party, path string, method func(*global.User, *[]model.ProjectPhaseExpenseLst) error) {

	RegisterMultiProjectPhaseExpenseLst(party, "PUT", path, method)
}
