// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package pj

import (
	"LEIT_PM/global"
	"LEIT_PM/grmi"
	model "LEIT_PM/models/pj"
	"LEIT_PM/web/middleware/jwts"
	"LEIT_PM/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneProjectPhaseExpensePeopleLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条ProjectPhaseExpensePeopleLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-09 11:17:04
 *
 ******************************************************************************/
func RegisterOneProjectPhaseExpensePeopleLst(party router.Party, httpMethod string, path string, method func(*global.User, *model.ProjectPhaseExpensePeopleLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.ProjectPhaseExpensePeopleLst)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfProjectPhaseExpensePeopleLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条ProjectPhaseExpensePeopleLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-09 11:17:04
 *
 ******************************************************************************/
func RegisterIDOfProjectPhaseExpensePeopleLst(party router.Party, httpMethod string, path string, method func(*global.User, string, string, int, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		projectId := ctx.Params().GetString("projectId")
		phaseId := ctx.Params().GetString("phaseId")
		pos, err := ctx.Params().GetInt("pos")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		name := ctx.Params().GetString("name")

		err = method(user, projectId, phaseId, pos, name)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneProjectPhaseExpensePeopleLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条ProjectPhaseExpensePeopleLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-09 11:17:04
 *
 ******************************************************************************/
func RegisterInsertOneProjectPhaseExpensePeopleLst(party router.Party, path string, method func(*global.User, *model.ProjectPhaseExpensePeopleLst) error) {

	RegisterOneProjectPhaseExpensePeopleLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneProjectPhaseExpensePeopleLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条ProjectPhaseExpensePeopleLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-09 11:17:04
 *
 ******************************************************************************/
func RegisterDeleteOneProjectPhaseExpensePeopleLst(party router.Party, path string, method func(*global.User, string, string, int, string) error) {

	RegisterIDOfProjectPhaseExpensePeopleLst(party, "DELETE", path+"/{projectId:string}/{phaseId:string}/{pos:int}/{name:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneProjectPhaseExpensePeopleLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条ProjectPhaseExpensePeopleLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-09 11:17:04
 *
 ******************************************************************************/
func RegisterSelectOneProjectPhaseExpensePeopleLst(party router.Party, path string, method func(*global.User, string, string, int, string) (*model.ProjectPhaseExpensePeopleLst, error)) {

	party.Get(path+"/{projectId:string}/{phaseId:string}/{pos:int}/{name:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		projectId := ctx.Params().GetString("projectId")
		phaseId := ctx.Params().GetString("phaseId")
		pos, err := ctx.Params().GetInt("pos")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		name := ctx.Params().GetString("name")
		result, err := method(user, projectId, phaseId, pos, name)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneProjectPhaseExpensePeopleLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条ProjectPhaseExpensePeopleLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-09 11:17:04
 *
 ******************************************************************************/
func RegisterUpdateOneProjectPhaseExpensePeopleLst(party router.Party, path string, method func(*global.User, *model.ProjectPhaseExpensePeopleLst) error) {

	RegisterOneProjectPhaseExpensePeopleLst(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiProjectPhaseExpensePeopleLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条ProjectPhaseExpensePeopleLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-09 11:17:04
 *
 ******************************************************************************/
func RegisterMultiProjectPhaseExpensePeopleLst(party router.Party, httpMethod string, path string, method func(*global.User, *[]model.ProjectPhaseExpensePeopleLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.ProjectPhaseExpensePeopleLst, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertProjectPhaseExpensePeopleLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条ProjectPhaseExpensePeopleLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-09 11:17:04
 *
 ******************************************************************************/
func RegisterInsertProjectPhaseExpensePeopleLst(party router.Party, path string, method func(*global.User, *[]model.ProjectPhaseExpensePeopleLst) error) {

	RegisterMultiProjectPhaseExpensePeopleLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteProjectPhaseExpensePeopleLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条ProjectPhaseExpensePeopleLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-09 11:17:04
 *
 ******************************************************************************/
func RegisterDeleteProjectPhaseExpensePeopleLst(party router.Party, path string, method func(*global.User, *[]model.ProjectPhaseExpensePeopleLst) error) {

	RegisterMultiProjectPhaseExpensePeopleLst(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectProjectPhaseExpensePeopleLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ProjectPhaseExpensePeopleLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-09 11:17:04
 *
 ******************************************************************************/
func RegisterSelectProjectPhaseExpensePeopleLst(party router.Party, path string, method func(*global.User, map[string]string) ([]model.ProjectPhaseExpensePeopleLst, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterQueryProjectPhaseExpensePeopleLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ProjectPhaseExpensePeopleLst并分页的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-09 11:17:04
 *
 ******************************************************************************/
func RegisterQueryProjectPhaseExpensePeopleLst(party router.Party, path string, method func(*global.User, map[string]string) (grmi.PagingResult, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateProjectPhaseExpensePeopleLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条ProjectPhaseExpensePeopleLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-09 11:17:04
 *
 ******************************************************************************/
func RegisterUpdateProjectPhaseExpensePeopleLst(party router.Party, path string, method func(*global.User, *[]model.ProjectPhaseExpensePeopleLst) error) {

	RegisterMultiProjectPhaseExpensePeopleLst(party, "PUT", path, method)
}
