// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package pj

import (
	"LEIT_PM/global"
	"LEIT_PM/grmi"
	model "LEIT_PM/models/pj"
	"LEIT_PM/web/middleware/jwts"
	"LEIT_PM/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneProjectPhaseLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条ProjectPhaseLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterOneProjectPhaseLst(party router.Party, httpMethod string, path string, method func(*global.User, *model.ProjectPhaseLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.ProjectPhaseLst)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfProjectPhaseLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条ProjectPhaseLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterIDOfProjectPhaseLst(party router.Party, httpMethod string, path string, method func(*global.User, string, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		projectId := ctx.Params().GetString("projectId")
		phaseId := ctx.Params().GetString("phaseId")

		err = method(user, projectId, phaseId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneProjectPhaseLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条ProjectPhaseLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterInsertOneProjectPhaseLst(party router.Party, path string, method func(*global.User, *model.ProjectPhaseLst) error) {

	RegisterOneProjectPhaseLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneProjectPhaseLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条ProjectPhaseLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterDeleteOneProjectPhaseLst(party router.Party, path string, method func(*global.User, string, string) error) {

	RegisterIDOfProjectPhaseLst(party, "DELETE", path+"/{projectId:string}/{phaseId:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneProjectPhaseLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条ProjectPhaseLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterSelectOneProjectPhaseLst(party router.Party, path string, method func(*global.User, string, string) (*model.ProjectPhaseLst, error)) {

	party.Get(path+"/{projectId:string}/{phaseId:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		projectId := ctx.Params().GetString("projectId")
		phaseId := ctx.Params().GetString("phaseId")
		result, err := method(user, projectId, phaseId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneProjectPhaseLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条ProjectPhaseLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterUpdateOneProjectPhaseLst(party router.Party, path string, method func(*global.User, *model.ProjectPhaseLst) error) {

	RegisterOneProjectPhaseLst(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiProjectPhaseLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条ProjectPhaseLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterMultiProjectPhaseLst(party router.Party, httpMethod string, path string, method func(*global.User, *[]model.ProjectPhaseLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.ProjectPhaseLst, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertProjectPhaseLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条ProjectPhaseLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterInsertProjectPhaseLst(party router.Party, path string, method func(*global.User, *[]model.ProjectPhaseLst) error) {

	RegisterMultiProjectPhaseLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteProjectPhaseLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条ProjectPhaseLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterDeleteProjectPhaseLst(party router.Party, path string, method func(*global.User, *[]model.ProjectPhaseLst) error) {

	RegisterMultiProjectPhaseLst(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectProjectPhaseLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ProjectPhaseLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterSelectProjectPhaseLst(party router.Party, path string, method func(*global.User, map[string]string) ([]model.ProjectPhaseLst, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterQueryProjectPhaseLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ProjectPhaseLst并分页的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterQueryProjectPhaseLst(party router.Party, path string, method func(*global.User, map[string]string) (grmi.PagingResult, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateProjectPhaseLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条ProjectPhaseLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterUpdateProjectPhaseLst(party router.Party, path string, method func(*global.User, *[]model.ProjectPhaseLst) error) {

	RegisterMultiProjectPhaseLst(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterPreadJustProjectPhaseLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个单条ProjectPhaseLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterPreadJustProjectPhaseLst(party router.Party, path string, method func(*global.User, string, string) (error)) {

	party.Post(path+"/{projectId:string}/{phaseId:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		projectId := ctx.Params().GetString("projectId")
		phaseId := ctx.Params().GetString("phaseId")
		err := method(user, projectId, phaseId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterCloseProjectPhaseLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个单条ProjectPhaseLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterCloseProjectPhaseLst(party router.Party, path string, method func(*global.User, string, string) (error)) {

	party.Post(path+"/{projectId:string}/{phaseId:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		projectId := ctx.Params().GetString("projectId")
		phaseId := ctx.Params().GetString("phaseId")
		err := method(user, projectId, phaseId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}
