// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package pj

import (
	"LEIT_PM/global"
	"LEIT_PM/grmi"
	model "LEIT_PM/models/pj"
	"LEIT_PM/web/middleware/jwts"
	"LEIT_PM/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
	"time"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneProjectPhaseResourceLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条ProjectPhaseResourceLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterOneProjectPhaseResourceLst(party router.Party, httpMethod string, path string, method func(*global.User, *model.ProjectPhaseResourceLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.ProjectPhaseResourceLst)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfProjectPhaseResourceLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条ProjectPhaseResourceLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterIDOfProjectPhaseResourceLst(party router.Party, httpMethod string, path string, method func(*global.User, string, string, string, grmi.Date) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		projectId := ctx.Params().GetString("projectId")
		phaseId := ctx.Params().GetString("phaseId")
		resourceId := ctx.Params().GetString("resourceId")
		planStartDateOrigin, err := time.Parse(grmi.URLDateFormat, ctx.Params().GetString("planStartDate"))
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		planStartDate := grmi.Date(planStartDateOrigin)

		err = method(user, projectId, phaseId, resourceId, planStartDate)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneProjectPhaseResourceLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条ProjectPhaseResourceLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterInsertOneProjectPhaseResourceLst(party router.Party, path string, method func(*global.User, *model.ProjectPhaseResourceLst) error) {

	RegisterOneProjectPhaseResourceLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneProjectPhaseResourceLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条ProjectPhaseResourceLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterDeleteOneProjectPhaseResourceLst(party router.Party, path string, method func(*global.User, string, string, string, grmi.Date) error) {

	RegisterIDOfProjectPhaseResourceLst(party, "DELETE", path+"/{projectId:string}/{phaseId:string}/{resourceId:string}/{planStartDate:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneProjectPhaseResourceLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条ProjectPhaseResourceLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterSelectOneProjectPhaseResourceLst(party router.Party, path string, method func(*global.User, string, string, string, grmi.Date) (*model.ProjectPhaseResourceLst, error)) {

	party.Get(path+"/{projectId:string}/{phaseId:string}/{resourceId:string}/{planStartDate:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		projectId := ctx.Params().GetString("projectId")
		phaseId := ctx.Params().GetString("phaseId")
		resourceId := ctx.Params().GetString("resourceId")
		planStartDateOrigin, err := time.Parse(grmi.URLDateTimeFormat, ctx.Params().GetString("planStartDate"))
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		planStartDate := grmi.Date(planStartDateOrigin)
		result, err := method(user, projectId, phaseId, resourceId, planStartDate)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneProjectPhaseResourceLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条ProjectPhaseResourceLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterUpdateOneProjectPhaseResourceLst(party router.Party, path string, method func(*global.User, *model.ProjectPhaseResourceLst) error) {

	RegisterOneProjectPhaseResourceLst(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiProjectPhaseResourceLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条ProjectPhaseResourceLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterMultiProjectPhaseResourceLst(party router.Party, httpMethod string, path string, method func(*global.User, *[]model.ProjectPhaseResourceLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.ProjectPhaseResourceLst, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertProjectPhaseResourceLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条ProjectPhaseResourceLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterInsertProjectPhaseResourceLst(party router.Party, path string, method func(*global.User, *[]model.ProjectPhaseResourceLst) error) {

	RegisterMultiProjectPhaseResourceLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteProjectPhaseResourceLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条ProjectPhaseResourceLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterDeleteProjectPhaseResourceLst(party router.Party, path string, method func(*global.User, *[]model.ProjectPhaseResourceLst) error) {

	RegisterMultiProjectPhaseResourceLst(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectProjectPhaseResourceLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ProjectPhaseResourceLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterSelectProjectPhaseResourceLst(party router.Party, path string, method func(*global.User, map[string]string) ([]model.ProjectPhaseResourceLst, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterQueryProjectPhaseResourceLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ProjectPhaseResourceLst并分页的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterQueryProjectPhaseResourceLst(party router.Party, path string, method func(*global.User, map[string]string) (grmi.PagingResult, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateProjectPhaseResourceLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条ProjectPhaseResourceLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-06 13:59:55
 *
 ******************************************************************************/
func RegisterUpdateProjectPhaseResourceLst(party router.Party, path string, method func(*global.User, *[]model.ProjectPhaseResourceLst) error) {

	RegisterMultiProjectPhaseResourceLst(party, "PUT", path, method)
}
