// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package pj

import (
	"LEIT_PM/global"
	"LEIT_PM/grmi"
	model "LEIT_PM/models/pj"
	"LEIT_PM/web/middleware/jwts"
	"LEIT_PM/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
	"time"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneProjectPhaseResourcePeopleLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条ProjectPhaseResourcePeopleLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-09 11:17:04
 *
 ******************************************************************************/
func RegisterOneProjectPhaseResourcePeopleLst(party router.Party, httpMethod string, path string, method func(*global.User, *model.ProjectPhaseResourcePeopleLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.ProjectPhaseResourcePeopleLst)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfProjectPhaseResourcePeopleLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条ProjectPhaseResourcePeopleLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-09 11:17:04
 *
 ******************************************************************************/
func RegisterIDOfProjectPhaseResourcePeopleLst(party router.Party, httpMethod string, path string, method func(*global.User, string, string, string, string, grmi.Date) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		projectId := ctx.Params().GetString("projectId")
		phaseId := ctx.Params().GetString("phaseId")
		resourceId := ctx.Params().GetString("resourceId")
		name := ctx.Params().GetString("name")
		planStartDateOrigin, err := time.Parse(grmi.URLDateFormat, ctx.Params().GetString("planStartDate"))
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		planStartDate := grmi.Date(planStartDateOrigin)

		err = method(user, projectId, phaseId, resourceId, name, planStartDate)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneProjectPhaseResourcePeopleLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条ProjectPhaseResourcePeopleLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-09 11:17:04
 *
 ******************************************************************************/
func RegisterInsertOneProjectPhaseResourcePeopleLst(party router.Party, path string, method func(*global.User, *model.ProjectPhaseResourcePeopleLst) error) {

	RegisterOneProjectPhaseResourcePeopleLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneProjectPhaseResourcePeopleLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条ProjectPhaseResourcePeopleLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-09 11:17:04
 *
 ******************************************************************************/
func RegisterDeleteOneProjectPhaseResourcePeopleLst(party router.Party, path string, method func(*global.User, string, string, string, string, grmi.Date) error) {

	RegisterIDOfProjectPhaseResourcePeopleLst(party, "DELETE", path+"/{projectId:string}/{phaseId:string}/{resourceId:string}/{name:string}/{planStartDate:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneProjectPhaseResourcePeopleLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条ProjectPhaseResourcePeopleLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-09 11:17:04
 *
 ******************************************************************************/
func RegisterSelectOneProjectPhaseResourcePeopleLst(party router.Party, path string, method func(*global.User, string, string, string, string, grmi.Date) (*model.ProjectPhaseResourcePeopleLst, error)) {

	party.Get(path+"/{projectId:string}/{phaseId:string}/{resourceId:string}/{name:string}/{planStartDate:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		projectId := ctx.Params().GetString("projectId")
		phaseId := ctx.Params().GetString("phaseId")
		resourceId := ctx.Params().GetString("resourceId")
		name := ctx.Params().GetString("name")
		planStartDateOrigin, err := time.Parse(grmi.URLDateTimeFormat, ctx.Params().GetString("planStartDate"))
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		planStartDate := grmi.Date(planStartDateOrigin)
		result, err := method(user, projectId, phaseId, resourceId, name, planStartDate)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneProjectPhaseResourcePeopleLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条ProjectPhaseResourcePeopleLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-09 11:17:04
 *
 ******************************************************************************/
func RegisterUpdateOneProjectPhaseResourcePeopleLst(party router.Party, path string, method func(*global.User, *model.ProjectPhaseResourcePeopleLst) error) {

	RegisterOneProjectPhaseResourcePeopleLst(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiProjectPhaseResourcePeopleLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条ProjectPhaseResourcePeopleLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-09 11:17:04
 *
 ******************************************************************************/
func RegisterMultiProjectPhaseResourcePeopleLst(party router.Party, httpMethod string, path string, method func(*global.User, *[]model.ProjectPhaseResourcePeopleLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.ProjectPhaseResourcePeopleLst, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertProjectPhaseResourcePeopleLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条ProjectPhaseResourcePeopleLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-09 11:17:04
 *
 ******************************************************************************/
func RegisterInsertProjectPhaseResourcePeopleLst(party router.Party, path string, method func(*global.User, *[]model.ProjectPhaseResourcePeopleLst) error) {

	RegisterMultiProjectPhaseResourcePeopleLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteProjectPhaseResourcePeopleLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条ProjectPhaseResourcePeopleLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-09 11:17:04
 *
 ******************************************************************************/
func RegisterDeleteProjectPhaseResourcePeopleLst(party router.Party, path string, method func(*global.User, *[]model.ProjectPhaseResourcePeopleLst) error) {

	RegisterMultiProjectPhaseResourcePeopleLst(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectProjectPhaseResourcePeopleLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ProjectPhaseResourcePeopleLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-09 11:17:04
 *
 ******************************************************************************/
func RegisterSelectProjectPhaseResourcePeopleLst(party router.Party, path string, method func(*global.User, map[string]string) ([]model.ProjectPhaseResourcePeopleLst, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterQueryProjectPhaseResourcePeopleLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ProjectPhaseResourcePeopleLst并分页的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-09 11:17:04
 *
 ******************************************************************************/
func RegisterQueryProjectPhaseResourcePeopleLst(party router.Party, path string, method func(*global.User, map[string]string) (grmi.PagingResult, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateProjectPhaseResourcePeopleLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条ProjectPhaseResourcePeopleLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-09 11:17:04
 *
 ******************************************************************************/
func RegisterUpdateProjectPhaseResourcePeopleLst(party router.Party, path string, method func(*global.User, *[]model.ProjectPhaseResourcePeopleLst) error) {

	RegisterMultiProjectPhaseResourcePeopleLst(party, "PUT", path, method)
}
